clear all
set more off

// Define source folders:

global dir_core = "$maindir\Main analysis" 
global dir_wage = "$maindir\Country analysis\Wage" 
global dir_earnwagesample = "$maindir\Country analysis\Earningswagesample" 
global dir_workrelben = "$maindir\Country analysis\Workrelbenoursample" 
global dir_dispinc = "$maindir\Country analysis\Dispincomeindoursample" 
global dir_natives_earn = "$maindir\Country analysis\Exclforeign" 
global dir_natives_dispinc = "$maindir\Country analysis\Dispincnat" 
global dir_natives_workrelben = "$maindir\Country analysis\Workrelnat" 
global dir_immigrants_earn = "$maindir\Country analysis\Foreignborns" 
global dir_immigrants_dispinc = "$maindir\Country analysis\Dispincfb" 
global dir_immigrants_workrelben = "$maindir\Country analysis\Workrelfb"
global dir_euam_earn = "$maindir\Country analysis\Fbwest" 
global dir_euam_dispinc = "$maindir\Country analysis\Dispincwest" 
global dir_euam_workrelben = "$maindir\Country analysis\Workrelwest"	
global dir_aame_earn = "$maindir\Country analysis\Fbnonwest" 
global dir_aame_dispinc = "$maindir\Country analysis\Dispincnonwest" 
global dir_aame_workrelben = "$maindir\Country analysis\Workrelnonwest"

global datasetup = "yes"
global graphswages = "yes"
global graphsdispinc = "yes"
global graphsincbyorigin = "yes"
global graphshigher = "yes"

// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	
	global legesize =     "large"	

global receyears = "1985,1986,1990,1991,1992,1996,2001,2002,2008,2011,2012,2016,2017"

// Where the figures are going to be saved 
capture noisily mkdir "$maindir\Figs\maininsurance"
global outfolder="$maindir\Figs\maininsurance\"	
global folderfile = "${outfolder}"

if "${datasetup}" == "yes"{
	
*** Wage sample: wages and earnings	
	
*** wages
	cd "$dir_wage" 	
	do "do\0_Initialize.do"
	
	foreach var in researn {
	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_wages
	}
	
	save "$folderfile\timeseries_wages.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100
	local var researn
	if "`subgp'" == "male" {  	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_wages_`subgp'
	}
	
	save "$folderfile\timeseries_wages_`subgp'.dta", replace
	
}
	
*** earnings for wage sample

	cd "$dir_earnwagesample" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_earnwage
	}
	
	save "$folderfile\timeseries_earnwage.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_earnwage_`subgp'
	}
	
	save "$folderfile\timeseries_earnwage_`subgp'.dta", replace
	
}
		

*** Full sample: work-related income and disposable income	

*** Earnings

	cd "$dir_main" 	
	do "do\0_Initialize.do"

	global ineqdata = "Inequality"			// Data on Inequality 
	global voladata = "Volatility"			// Data on Volatility
	global mobidata = "Mobility"			// Data on Mobility
	
	foreach subgp in male fem{
    sleep 100    
	local var researn
*	local subgp male
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*Load data by gender and by gender-education group: 
	if "`subgp'" == "male" {  
		local labname "Male"
	    * load inequality measures
		insheet using "out${sep}${ineqdata}${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}${voladata}${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1	
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {
		local labname "Female"
	    * load inequality measures
		insheet using "out${sep}${ineqdata}${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}${voladata}${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0	
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
	* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_`subgp'
	}
	
	save "$folderfile\timeseries_`subgp'.dta", replace
	
	}


*** work-related income

	cd "$dir_workrelben" 	
	do "do\0_Initialize.do"
	
	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben
	}
	
	save "$folderfile\timeseries_workrelben.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben_`subgp'
	}
	
	save "$folderfile\timeseries_workrelben_`subgp'.dta", replace
	
}
	
*** disposible income
	
	cd "$dir_dispinc" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc
	}
	
	save "$folderfile\timeseries_dispinc.dta", replace
	
}
	
	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc_`subgp'
	}
	
	save "$folderfile\timeseries_dispinc_`subgp'.dta", replace
	
}
	
    
*** natives

	cd "$dir_natives_earn" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_natives
	}
	
	save "$folderfile\timeseries_natives.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_natives_`subgp'
	}
	
	save "$folderfile\timeseries_natives_`subgp'.dta", replace
	
}
	
	
	cd "$dir_natives_dispinc" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc
	}
	
	save "$folderfile\timeseries_natives_dispinc.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc_`subgp'
	}
	
	save "$folderfile\timeseries_natives_dispinc_`subgp'.dta", replace
	
}
	
	
	cd "$dir_natives_workrelben" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben
	}
	
	save "$folderfile\timeseries_natives_workrelben.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben_`subgp'
	}
	
	save "$folderfile\timeseries_natives_workrelben_`subgp'.dta", replace
	
}
	
*** foreign-born
		
	cd "$dir_immigrants_earn" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_foreign
	}
	
	save "$folderfile\timeseries_foreign.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_foreign_`subgp'
	}
	
	save "$folderfile\timeseries_foreign_`subgp'.dta", replace
	
}
	

	cd "$dir_immigrants_dispinc" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc
	}
	
	save "$folderfile\timeseries_foreign_dispinc.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc_`subgp'
	}
	
	save "$folderfile\timeseries_foreign_dispinc_`subgp'.dta", replace
	
}
	

	cd "$dir_immigrants_workrelben" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben
	}
	
	save "$folderfile\timeseries_foreign_workrelben.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben_`subgp'
	}
	
	save "$folderfile\timeseries_foreign_workrelben_`subgp'.dta", replace
	
}
	

*** Europe and Americas

	cd "$dir_euam_earn" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_foreign
	}
	
	save "$folderfile\timeseries_west.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_foreign_`subgp'
	}
	
	save "$folderfile\timeseries_west_`subgp'.dta", replace
	
}
	
	
	cd "$dir_euam_dispinc" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc
	}
	
	save "$folderfile\timeseries_west_dispinc.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc_`subgp'
	}
	
	save "$folderfile\timeseries_west_dispinc_`subgp'.dta", replace
	
}
	
	
	cd "$dir_euam_workrelben" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben
	}
	
	save "$folderfile\timeseries_west_workrelben.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben_`subgp'
	}
	
	save "$folderfile\timeseries_west_workrelben_`subgp'.dta", replace
	
}
	
	
*** Africa, Asia, Middle East
	
	cd "$dir_aame_earn" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_foreign
	}
	
	save "$folderfile\timeseries_nonwest.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_foreign_`subgp'
	}
	
	save "$folderfile\timeseries_nonwest_`subgp'.dta", replace
	
}
	

	cd "$dir_aame_dispinc" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc
	}
	
	save "$folderfile\timeseries_nonwest_dispinc.dta", replace
	
}

	foreach subgp in male fem{
     sleep 100   
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_dispinc_`subgp'
	}
	
	save "$folderfile\timeseries_nonwest_dispinc_`subgp'.dta", replace
	
}
	

	cd "$dir_aame_workrelben" 	
	do "do\0_Initialize.do"

	foreach var in researn {
    sleep 100	
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_sumstat.csv", clear
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_sumstat.csv", clear
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_sumstat.csv", clear
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben
	}
	
	save "$folderfile\timeseries_nonwest_workrelben.dta", replace
	
}

	foreach subgp in male fem{
    sleep 100    
	local var researn
	if "`subgp'" == "male" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 1
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 1
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}
	if "`subgp'" == "fem" {  		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_logearn_male_sumstat.csv", clear
		keep if male == 0
		keep year p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn p99logearn
		save temp1, replace
		
	    * load inequality measures
		insheet using "out${sep}Inequality${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var' p10`var' p50`var' p90`var'
		save temp2, replace
		
	    * load volatility measures
		insheet using "out${sep}Volatility${sep}L_`var'1F_male_sumstat.csv", clear
		keep if male == 0
		keep year sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f  p95`var'1f p5`var'1f p25`var'1f p75`var'1f
		save temp3, replace	
	}	
	merge 1:1 year using temp1
	drop _merge
	merge 1:1 year using temp2
	drop _merge
	
		* Define percentile measures:
	gen p9010`var' = p90`var' - p10`var'
	gen p9050`var' = p90`var' - p50`var'
	gen p5010`var' = p50`var' - p10`var'
	
	gen p9010`var'1f = p90`var'1f - p10`var'1f
	gen p9050`var'1f = p90`var'1f - p50`var'1f
	gen p5010`var'1f = p50`var'1f - p10`var'1f
	
	gen kelley`var'1f = (p9050`var'1f - p5010`var'1f)/p9010`var'1f
	gen crow`var'1f = (p95`var'1f - p5`var'1f)/(p75`var'1f - p25`var'1f)
	
	foreach varn of varlist p1logearn p10logearn p25logearn p50logearn p75logearn p90logearn ///
	sd`var' p10`var' p50`var' p90`var' p9010`var' p9050`var' p5010`var' ///
	sd`var'1f skew`var'1f kurt`var'1f p10`var'1f p50`var'1f p90`var'1f ///
	p95`var'1f p5`var'1f p25`var'1f p75`var'1f ///
	p9010`var'1f p9050`var'1f p5010`var'1f kelley`var'1f crow`var'1f {
	    rename `varn' `varn'_workrelben_`subgp'
	}
	
	save "$folderfile\timeseries_nonwest_workrelben_`subgp'.dta", replace
	
}
	
}	
	

/*---------------------------------------------------	
    Wages and Earnings
 ---------------------------------------------------*/

if "${graphswages}" == "yes" {	
 	
	local outcomelist ""p9010researn" "p9010researn1f" "p9050researn" "p9050researn1f" "p5010researn" "p5010researn1f" " 
	local titlelist ""90-10 Earnings Gap" "90-10 Gap in Earnings Growth" "90-50 Earnings Gap" "90-50 Gap in Earnings Growth" "50-10 Earnings Gap" "50-10 Gap in Earnings Growth" " 
	local namelist ""9010Gap" "9010Growth" "9050Gap" "9050Growth" "5010Gap" "5010Growth" "	

local kk = 1
foreach subgp in male fem {
	local k = 1
	forvalues jj = 1/6 {
	use "$folderfile\timeseries_earnwage_`subgp'.dta", clear
	
	local outcome : word `k' of `outcomelist'	
	local title : word `k' of `titlelist'
	local subname : word `k' of `namelist'
	
	keep year `outcome'_*
    rename `outcome'_earnwage_`subgp' `outcome'_1 
    
	merge 1:1 year using "$folderfile\timeseries_wages_`subgp'.dta", keep(match)
	drop _merge
	
	keep year `outcome'_*
    rename `outcome'_wages `outcome'_2 

	sort year
	gen rece = inlist(year,${receyears})
	
	*Defining plot limits
	if `kk' == 1 {
	if `jj'==1 {
		local y1bot = 1.2
		local y1top = 1.65
		local y2bot = 0.4
		local y2top = 0.85
		local scale = 0.1
	}
	if `jj'==2 {
		local y1bot = 0.5
		local y1top = 0.8
		local y2bot = 0
		local y2top = 0.3
		local scale = 0.1
	}
	if `jj'==3 {
		local y1bot = 0.4
		local y1top = 0.65
		local y2bot = 0.3
		local y2top = 0.55
		local scale = 0.1
	}
	if `jj'==5 {
		local y1bot = 0.65
		local y1top = 1.1
		local y2bot = 0.1
		local y2top = 0.55
		local scale = 0.15
	}
	if `jj'==4 {
		local y1bot = 0.2
		local y1top = 0.42
		local y2bot = 0
		local y2top = 0.22
		local scale = 0.1
	}
	if `jj'==6 {
		local y1bot = 0.2
		local y1top = 0.42
		local y2bot = 0
		local y2top = 0.22
		local scale = 0.1
	}
	}
	if `kk' == 2 {
	if `jj'==1 {
		local y1bot = 1.2
		local y1top = 1.65
		local y2bot = 0.4
		local y2top = 0.85
		local scale = 0.1
	}
	if `jj'==2 {
		local y1bot = 0.8
		local y1top = 1.1
		local y2bot = 0
		local y2top = 0.3
		local scale = 0.1
	}
	if `jj'==3 {
		local y1bot = 0.4
		local y1top = 0.65
		local y2bot = 0.2
		local y2top = 0.45
		local scale = 0.1
	}
	if `jj'==5 {
		local y1bot = 0.85
		local y1top = 1.1
		local y2bot = 0.1
		local y2top = 0.35
		local scale = 0.1
	}
	if `jj'==4 {
		local y1bot = 0.35
		local y1top = 0.62
		local y2bot = 0
		local y2top = 0.27
		local scale = 0.1
	}
	if `jj'==6 {
		local y1bot = 0.35
		local y1top = 0.62
		local y2bot = 0
		local y2top = 0.27
		local scale = 0.1
	}
	}
	
	qui: gen receup = `y1top'*rece if rece == 1
	qui: gen recedo = `y1bot'*rece if rece == 1
	
*Plot
disp `y1bot'
disp `y1top'
disp `y2bot'
disp `y2top'
disp `scale'

sum year
local minyear = r(min)
local maxyear = r(max)
tw	(rbar recedo receup year, c(l) color(gray*0.5)) ///
	(connected `outcome'_1 year, msymbol(D) color(navy) yaxis(1)) ///
	(connected `outcome'_2 year, msymbol(T) color(maroon) yaxis(2)), ///
	legend(order(2 3) label(2 "Earnings") label(3 "Wages") region(color(none) lcolor(white)) ring(0) position(1) col(1) size("large")) ///
	xtitle(Year, size("large")) ///
	yscale(range(`y1bot'(0.1)`y1top') axis(1)) ylabel(`y1bot'(`scale')`y1top', axis(1) labsize("large")) ///
	yscale(range(`y2bot'(0.1)`y2top') axis(2)) ylabel(`y2bot'(`scale')`y2top', axis(2) labsize("large")) ///
	ytitle("Earnings", axis(1) size("large")) ytitle("Wages", axis(2) size("large")) ///
	graphregion(color(white)) xlabel(`minyear'(5)`maxyear',grid labsize("large"))
	
	graph export "$folderfile\summary_timeseries_wages_`subname'_`subgp'_manual.pdf", replace

	local k = `k' + 1
	}
local kk = `kk' + 1
	}

	
/*----------------------------------------
	Cohorts and Initial Inequality
------------------------------------------*/
	
	cd "$dir_wage" 	
	do "do\0_Initialize.do"
	
	global folderfile = "${outfolder}"
	global ineqdata = "Inequality"	// Data on Inequality 	

	do "$maindir/do/myplots_BF.do"	
	
foreach var in logearn{	// Add here other variables 
	foreach subgp in male fem{			// Add here other groups 
	
	// Plots by cohorts 			
	*Which variable is under analysis? 
	*The code generates for raw earnimgs and residuals earnigs
	global vari = "`var'"		
	
	*Label for plots
	local labtitle = "log y{sub:it}"
								
	*You can add more groups to this section 
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
		
		*Age 25
		local posi1= 0.35
		local posi2= 0.46
		local posi3= 0.32
		
		local yposi1= 1997
		local yposi2= 1998
		local yposi3= 1998
		
		*Age 35
		local posj1= 0.85
		local posj2= 0.72
		local posj3= 0.85
		
		local yposj1= 1998
		local yposj2= 2001
		local yposj3= 1998
		
	}	
	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
		
		*Age 25
		local posi1= 0.25
		local posi2= 0.35
		local posi3= 0.22
		
		local yposi1= 1997
		local yposi2= 1998
		local yposi3= 1998
		
		*Age 35
		local posj1= 0.7
		local posj2= 0.57
		local posj3= 0.7
		
		local yposj1= 2013
		local yposj2= 2014
		local yposj3= 2013

	}
		
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
	
	

	gkswplot_co "p9010`var'" "year" ///
			 "1985 1993 2000 2010" /// what cohorts?
			 "25 35" /// What ages: code allows three
			 "1990" "2015" "5" /// x-axis
			 "on" "7" "2" "Cohort 1985" "Cohort 1993" "Cohort 2000" "Cohort 2010" /// Legends
			 "" "P90-P10 of Log Earnings"  /// x and y titles 
			 "" "large" "" "" ///
			 "0" "0.9" "0.2" ///
			 "fig3B_wages_`subgp'_${vari}" ///
			 "`posi1'" "`yposi1'" "`posi2'" "`yposi2'" "`posi3'" "`yposi3'" "25 yrs old" ///
			 "`posj1'" "`yposj1'" "`posj2'" "`yposj2'" "`posj3'" "`yposj3'" "35 yrs old" 

	
}	// END loop subgroups
}	// END loop over variables 

}
 

/*---------------------------------------------------	
    Work-Related Benefits and Disposable Income
 ---------------------------------------------------*/

if "${graphsdispinc}" == "yes" {	

/*---------------------------------------------------	
    Comparison: Inequality
 ---------------------------------------------------*/
 
	local outcomelist ""p9010researn" "p9050researn" "p5010researn" " 
	local titlelist1 ""P90-10: Earnings" "P90-50: Earnings" "P50-10:  Earnings" " 
	local titlelist2 ""P90-10: Work-Related/Disposable Income" "P90-50: Work-Related/Disposable Income" "P50-10: Work-Related/Disposable Income" " 
	local namelist ""9010Gap" "9050Gap" "5010Gap" "	

// Graphs plotting outcomes on two y axes:

// LOOP over outcomes by gender
foreach subgp in male fem {
	local k = 1
	forvalues jj = 1/3 {
	use "$folderfile\timeseries_`subgp'.dta", clear
	
	local outcome : word `k' of `outcomelist'	
	local title1 : word `k' of `titlelist1'
	local title2 : word `k' of `titlelist2'
	local subname : word `k' of `namelist'
	
	keep year `outcome'_*
    rename `outcome'_`subgp' `outcome'_1 
	
	local j = 2
	foreach subgp2 in workrelben dispinc {
    
	merge 1:1 year using "$folderfile\timeseries_`subgp2'_`subgp'.dta", keep(match)
	drop _merge
	
	keep year `outcome'_*
    rename `outcome'_`subgp2' `outcome'_`j' 
	local j = `j' +1
	}

	sort year
	gen rece = inlist(year,${receyears})
	
	*Defining plot limits
	if `jj'==1 {
		local y1bot = 1.2
		local y1top = 1.65
		local y2bot = 0.7
		local y2top = 1.15
		local scale = 0.1
	}
	if `jj'==2 {
		local y1bot = 0.45
		local y1top = 0.6
		local y2bot = 0.35
		local y2top = 0.5
		local scale = 0.05
	}
	if `jj'==3 {
		local y1bot = 0.7
		local y1top = 1.1
		local y2bot = 0.3
		local y2top = 0.7
		local scale = 0.1
	}
	
	qui: gen receup = `y1top'*rece if rece == 1
	qui: gen recedo = `y1bot'*rece if rece == 1
	
*Plot
disp `y1bot'
disp `y1top'
disp `y2bot'
disp `y2top'
disp `scale'
sum year
local minyear = r(min)
local maxyear = r(max)
*Plot
tw	(rbar recedo receup  year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5)) ///
	(connected `outcome'_1 year, msymbol(D) color(navy) yaxis(1)) ///
	(connected `outcome'_2 year, msymbol(T) color(maroon) yaxis(2) ) ///
	(connected `outcome'_3 year,  msymbol(S) color(forest_green) yaxis(2) ), ///
	legend(cols(1) symxsize(7.0) ring(0) position(5) order(2 3 4 5) label(2 "Earnings") ///
	label(3 "Work-Rel Inc") label(4 "Disposable Inc") region(color(none) lcolor(white)) size("large")) ///
	yscale(range(`y1bot'(0.1)`y1top') axis(1)) ylabel(`y1bot'(`scale')`y1top', axis(1) labsize("large")) ///
	yscale(range(`y2bot'(0.1)`y2top') axis(2)) ylabel(`y2bot'(`scale')`y2top', axis(2) labsize("large")) ///
	ytitle("`title1'", axis(1) size("large"))  ///
	ytitle("`title2'", axis(2) size("large") ) ///
	graphregion(color(white)) xtitle("Year", size("large")) xlabel(`minyear'(5)`maxyear',grid labsize("large")) 
	
	graph export "$folderfile\summary_timeseries_incomes_`subname'_`subgp'_manual.pdf", replace

	local k = `k' + 1
	}
}


/*---------------------------------------------------	
    Comparison: Volatility
 ---------------------------------------------------*/
 
	local outcomelist ""p9010researn1f" "p9050researn1f" "p5010researn1f"" 
	local titlelist ""P90-10 of 1-Year Income Growth" "P90-50 of 1-Year Income Growth" "P50-10 of 1-Year Income Growth" " 
	local namelist ""9010Growth" "9050Growth" "5010Growth" "	

// Graphs plotting outcomes on two y axes:

// LOOP over outcomes by gender
foreach subgp in male fem {
	local k = 1
	forvalues jj = 1/3 {
	use "$folderfile\timeseries_`subgp'.dta", clear
	
	local outcome : word `k' of `outcomelist'	
	local title : word `k' of `titlelist'
	local subname : word `k' of `namelist'
	
	keep year `outcome'_*
    rename `outcome'_`subgp' `outcome'_1 
	
	local j = 2
	foreach subgp2 in workrelben dispinc {
    
	merge 1:1 year using "$folderfile\timeseries_`subgp2'_`subgp'.dta", keep(match)
	drop _merge
	
	keep year `outcome'_*
    rename `outcome'_`subgp2' `outcome'_`j' 
	local j = `j' +1
	}

	sort year
	gen rece = inlist(year,${receyears})
	
	*Defining plot limits
	if `jj'==1 {
		local y1bot = 0.3
		local y1top = 1.4
		local scale = 0.2
		local legpos = 1
	}
	if `jj'==2 {
		local y1bot = 0
		local y1top = 0.6
		local scale = 0.1
		local legpos = 5
		}
	if `jj'==3 {
		local y1bot = 0
		local y1top = 0.6
		local scale = 0.1
		local legpos = 5
		}
	
	qui: gen receup = `y1top'*rece if rece == 1
	qui: gen recedo = `y1bot'*rece if rece == 1
	
*Plot
disp `y1bot'
disp `y1top'
disp `y2bot'
disp `y2top'
disp `scale'
sum year
local minyear = r(min)
local maxyear = r(max)
*Plot
tw	(rbar recedo receup  year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5)) ///
	(connected `outcome'_1 year, msymbol(D) color(navy) ) ///
	(connected `outcome'_2 year, msymbol(T) color(maroon) ) ///
	(connected `outcome'_3 year,  msymbol(S) color(forest_green) ), ///
	legend(cols(1) symxsize(7.0) ring(0) position(`legpos') order(2 3 4 5) label(2 "Earnings") ///
	label(3 "Work-Rel Inc") label(4 "Disposable Inc") region(color(none) lcolor(white)) size("large")) ///
	yscale(range(`y1bot'(0.1)`y1top') axis(1)) ylabel(`y1bot'(`scale')`y1top', axis(1) labsize("large") grid) ///
	graphregion(color(white)) xtitle("Year", size("large")) xlabel(`minyear'(5)`maxyear', grid labsize("large")) ytitle(`title')
	
	graph export "$folderfile\summary_timeseries_incomes_`subname'_`subgp'_onescale.pdf", replace

	local k = `k' + 1
	}
}


/*---------------------------------------------------	
    Trends in Disposable Income Inequality
 ---------------------------------------------------*/

	cd "$dir_dispinc" 	
	do "do\0_Initialize.do"
	
	global folderfile = "${outfolder}"
	global ineqdata = "Inequality"	// Data on Inequality 	

	do "$maindir/do/myplots_BF.do"	

	
foreach subgp in fem male {	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn researn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_sumstat.csv", clear
		local labname = "All"
	}
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local labname = "Men"
	}
		
	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	
	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = 0
		local y2 = 0.65
		local y3 = 0.2
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local y1 = -0.15
		local y2 =  0.15
		local y3 = .05
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_dispinc_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 		   

// Figure 2 (Inequality)	
	if "${vari}" == "logearn"{
		local y1 = 0.7
		local y2 = 1.35
		local y3 = 0.1
	}
	if "${vari}" == "researn"{
		local y1 = 1.2
		local y2 = 1.65
		local y3 = 0.1
	}
	if "${vari}" == "researne" {
		local y1 = 1.2
		local y2 = 1.65
		local y3 = 0.1
	}
		   		   
	tspltAREALimPA "sd$vari p9010$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "2.56*{&sigma}" "P90-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2A_dispinc_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	   }	// END of loop over subgroups
	   
}		// END loop over variables


}	
	

/*---------------------------------------------------	
    Income Inequality and Volatility by Origin
 ---------------------------------------------------*/
 
if "${graphsincbyorigin}" == "yes" {	
	local outcomelist ""p9010researn" "p9010researn1f"" 
	local titlelist ""P90-10 of Log Income" "P90-10 of 1-Year Income Growth"" 
	local namelist ""9010Gap" "9010Growth""	

**** FOREIGN

// LOOP over outcomes by gender
foreach subgp in male fem {
	local k = 1
	forvalues jj = 1/2 {
	use "$folderfile\timeseries_foreign_`subgp'.dta", clear
	
	local outcome : word `k' of `outcomelist'	
	local title : word `k' of `titlelist'
	local subname : word `k' of `namelist'
	
	keep year `outcome'_*
    rename `outcome'_foreign_`subgp' `outcome'_1 
	
	local j = 2
	foreach subgp2 in workrelben dispinc {
    
	merge 1:1 year using "$folderfile\timeseries_foreign_`subgp2'_`subgp'.dta", keep(match)
	drop _merge
	
	keep year `outcome'_*
    rename `outcome'_`subgp2'_`subgp' `outcome'_`j' 
	local j = `j' +1
	}

	sort year
	gen rece = inlist(year,${receyears})
	
	*Defining plot limits
	if `jj'==1 {
		local y1bot = 0.8
		local y1top = 2.0
		local scale = 0.2
	}
	if `jj'==2 {
		local y1bot = 0.3
		local y1top = 1.4
		local scale = 0.2
	}
	
	qui: gen receup = `y1top'*rece if rece == 1
	qui: gen recedo = `y1bot'*rece if rece == 1
	
*Plot
disp `y1bot'
disp `y1top'
disp `scale'
sum year
local minyear = r(min)
local maxyear = r(max)
*Plot
tw	(rbar recedo receup  year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5)) ///
	(connected `outcome'_1 year, msymbol(D) color(navy)) ///
	(connected `outcome'_2 year, msymbol(T) color(maroon)) ///
	(connected `outcome'_3 year,  msymbol(S) color(forest_green) ), ///
	legend(cols(1) symxsize(7.0) ring(0) position(5) order(2 3 4 5) label(2 "Earnings") ///
	label(3 "Work-Rel Inc") label(4 "Disposable Inc") region(color(none) lcolor(white)) size("large")) ///
	yscale(range(`y1bot'(0.1)`y1top') axis(1)) ylabel(`y1bot'(`scale')`y1top', labsize("large") grid) ///
	graphregion(color(white)) xtitle("Year", size("large")) xlabel(`minyear'(5)`maxyear',grid labsize("large")) ytitle(`title')
	
	graph export "$folderfile\summary_timeseries_foreign_`subname'_`subgp'_onescale.pdf", replace

	local k = `k' + 1
	}
}


**** NATIVE

// LOOP over outcomes by gender
foreach subgp in male fem {
	local k = 1
	forvalues jj = 1/2 {
	use "$folderfile\timeseries_natives_`subgp'.dta", clear
	
	local outcome : word `k' of `outcomelist'	
	local title : word `k' of `titlelist'
	local subname : word `k' of `namelist'
	
	keep year `outcome'_*
    rename `outcome'_natives_`subgp' `outcome'_1 
	
	local j = 2
	foreach subgp2 in workrelben dispinc {
    
	merge 1:1 year using "$folderfile\timeseries_natives_`subgp2'_`subgp'.dta", keep(match)
	drop _merge
	
	keep year `outcome'_*
    rename `outcome'_`subgp2'_`subgp' `outcome'_`j' 
	local j = `j' +1
	}

	sort year
	gen rece = inlist(year,${receyears})
	
	*Defining plot limits
	if `jj'==1 {
		local y1bot = 0.8
		local y1top = 2.0
		local scale = 0.2
	}
	if `jj'==2 {
		local y1bot = 0.3
		local y1top = 1.4
		local scale = 0.2
	}
	
	qui: gen receup = `y1top'*rece if rece == 1
	qui: gen recedo = `y1bot'*rece if rece == 1
	
*Plot
disp `y1bot'
disp `y1top'
disp `scale'
sum year
local minyear = r(min)
local maxyear = r(max)
*Plot
tw	(rbar recedo receup  year, ylabel(,nogrid axis(1)) c(l) color(gray*0.5)) ///
	(connected `outcome'_1 year, msymbol(D) color(navy)) ///
	(connected `outcome'_2 year, msymbol(T) color(maroon)) ///
	(connected `outcome'_3 year,  msymbol(S) color(forest_green)), ///
	legend(cols(1) symxsize(7.0) ring(0) position(1) order(2 3 4 5) label(2 "Earnings") ///
	label(3 "Work-Rel Inc") label(4 "Disposable Inc") region(color(none) lcolor(white)) size("large")) ///
	yscale(range(`y1bot'(0.1)`y1top') axis(1)) ylabel(`y1bot'(`scale')`y1top', labsize("large") grid) ///
	graphregion(color(white)) xtitle("Year", size("large")) xlabel(`minyear'(5)`maxyear',grid labsize("large")) ytitle(`title') 
	
	graph export "$folderfile\summary_timeseries_natives_`subname'_`subgp'_onescale.pdf", replace

	local k = `k' + 1
	}
}

}


/*---------------------------------------------------	
    Higher-Order Moments by Origin
 ---------------------------------------------------*/

if "${graphshigher}" == "yes" {
	
global maindir1 ="$dir_immigrants_dispinc"

// Where the data is stored
global ineqdata1 = "Inequality"			// Data on Inequality 
global voladata1 = "Volatility"			// Data on Volatility
global mobidata1 = "Mobility"			// Data on Mobility

global maindir2 ="$dir_natives_dispinc"

// Where the data is stored
global ineqdata2 = "Inequality"			// Data on Inequality 
global voladata2 = "Volatility"			// Data on Volatility
global mobidata2 = "Mobility"			// Data on Mobility


*** Compare immigrants from different regions of the world:

global maindir3 ="$dir_euam_dispinc"

// Where the data is stored
global ineqdata3 = "Inequality"			// Data on Inequality 
global voladata3 = "Volatility"			// Data on Volatility
global mobidata3 = "Mobility"			// Data on Mobility

global maindir4 ="$dir_aame_dispinc"

// Where the data is stored
global ineqdata4 = "Inequality"			// Data on Inequality 
global voladata4 = "Volatility"			// Data on Volatility
global mobidata4 = "Mobility"			// Data on Mobility

global folderfile = "${outfolder}"	

// Define these variables for your dataset
global yrfirst = 1985 		// First year in the dataset 
global yrlast =  2016 		// Last year in the dataset
global Tcommon = ${yrlast} - 20 + 1	// number of years used for th plots

*** By Gender and Age Group:	
		foreach mm in  0 1 {		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
** Load and merge the data:
		forvalues xx = 1/4 {
		*Load the data for the last percentile
		cd "${maindir`xx'}"
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata`xx'}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata`xx'}${sep}L_`var'_agerank.csv", clear case	    
		}
		
		drop if year < ${Tcommon}
		
		*Calculate additional moments 
		gen p9010_`xx' = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}		
		gen ksk_`xx' = (p9050${vari} - p5010${vari})/p9010_`xx'
	
	
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
		
		gen bin = permrank/2.5
		replace bin = ceil(bin/2)
		replace permrank = 5*bin
		
		keep agegp permrank p9010* ksk*
		
		collapse  ksk_`xx' p9010_`xx', by(agegp permrank)
		reshape wide ksk_`xx' p9010_`xx', i(permrank) j(agegp)
		cd "${maindir4}"		
		save temp`xx', replace
		}
		
		merge 1:1 permrank using temp1
		drop _merge
		merge 1:1 permrank using temp2
		drop _merge		
		merge 1:1 permrank using temp3
		drop _merge
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Skewness:	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.2
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.2
			local ylimup = 0.25
			local ylimdf = 0.1		
		}

tw (connected ksk_11 ksk_21 ksk_31 ksk_41 permrank if idex<=42, msymbol(none none none none)  ///
		color(red blue maroon navy) lpattern(solid dash dash_dot longdash) lwidth(thick thick thick thick)), ///
		xlabel(5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "Foreign-Born" 2 "Native" 3 "Europe & Americas" 4 "Africa, Asia, M. East") size("large") cols(2) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size("large")) ///
		ytitle("Kelley Skewness of `labtitle'", size("large")) ///
		title("", color(black) size("large")) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize("large"))		
		graph export "${folderfile}/fig6B_${vari}_dispyoung_`lname'_byorigin.pdf", replace 
		
tw (connected ksk_12 ksk_22 ksk_32 ksk_42 permrank if idex<=42, msymbol(none none none none)  ///
		color(red blue maroon navy) lpattern(solid dash dash_dot longdash) lwidth(thick thick thick thick)), ///
		xlabel(5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "Foreign-Born" 2 "Native" 3 "Europe & Americas" 4 "Africa, Asia, M. East") size("large") cols(2) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size("large")) ///
		ytitle("Kelley Skewness of `labtitle'", size("large")) ///
		title("", color(black) size("large")) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize("large"))		
		graph export "${folderfile}/fig6B_${vari}_dispmid_`lname'_byorigin.pdf", replace 

		}	// END loop variables		
		}	// END loop men/women	

*** Across ALL age groups
		foreach mm in  0 1 {		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
** Load and merge the data:
		forvalues xx = 1/4 {
		*Load the data for the last percentile
		cd "${maindir`xx'}"
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata`xx'}${sep}L_`var'_malerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata`xx'}${sep}L_`var'_allrank.csv", clear case	    
		}
		
		drop if year < ${Tcommon}
		
		*Calculate additional moments 
		gen p9010_`xx' = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}		
		gen ksk_`xx' = (p9050${vari} - p5010${vari})/p9010_`xx'
	
	
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
		
		gen bin = permrank/2.5
		replace bin = ceil(bin/2)
		replace permrank = 5*bin
		
		keep permrank p9010* ksk*
		
		collapse  ksk_`xx' p9010_`xx', by(permrank)
		cd "${maindir4}"		
		save temp`xx', replace
		}
		
		merge 1:1 permrank using temp1
		drop _merge
		merge 1:1 permrank using temp2
		drop _merge		
		merge 1:1 permrank using temp3
		drop _merge
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 

		*Volatility		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.0
			local ylimup = 1.7
			local ylimdf = 0.5			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.0
			local ylimup = 2.5
			local ylimdf = 0.5		
		}
		
		tw (connected p9010_1 p9010_2 p9010_3 p9010_4 permrank if idex<=42, msymbol(none none none none)  ///
		color(red blue maroon navy) lpattern(solid dash dash_dot longdash) lwidth(thick thick thick thick)), ///
		xlabel(5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize("large") grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "Foreign-Born" 2 "Native" 3 "Europe & Americas" 4 "Africa, Asia, M. East") size("large") cols(2) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size("large")) ///
		ytitle("P90-P10 Differential of `labtitle'", size("large")) ///
		title("", color(black) size("large")) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize("large"))		
		graph export "${folderfile}/fig6A_${vari}_dispall_`lname'_byorigin.pdf", replace 
		
		*Skewness	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.2
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.2
			local ylimup = 0.25
			local ylimdf = 0.1		
		}

tw (connected ksk_1 ksk_2 ksk_3 ksk_4 permrank if idex<=42, msymbol(none none none none)  ///
		color(red blue maroon navy) lpattern(solid dash dash_dot longdash) lwidth(thick thick thick thick)), ///
		xlabel(5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize("large") grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "Foreign-Born" 2 "Native" 3 "Europe & Americas" 4 "Africa, Asia, M. East") size("large") cols(2) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size("large")) ///
		ytitle("Kelley Skewness of `labtitle'", size("large")) ///
		title("", color(black) size("large")) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize("large"))		
		graph export "${folderfile}/fig6B_${vari}_dispall_`lname'_byorigin.pdf", replace 

		}	// END loop variables		
		}	// END loop men/women	

}


	
	

