// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This code generates the figures by origin
// This version January 25, 2022
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

clear all
set more off

// Which results are generated 
	global migrants =  "yes"		// All Foreign-Born
	global natives =   "yes"		// All Natives
	global byorigin =  "yes"		// Foreign vs Natives 
	global migrantsbyregion = "yes" // Foreign by Region	
	global byoriginregion =  "yes"	// Natives vs Foreign by Region

// Define source folders:

// Foreign-Born:
global maindir_foreign ="$maindir/Country analysis/Foreignborns"
global ineqdata_foreign = "Inequality"			// Data on Inequality 
global voladata_foreign = "Volatility"			// Data on Volatility
global mobidata_foreign = "Mobility"			// Data on Mobility

// Natives:
global maindir_natives ="$maindir/Country analysis/Exclforeign"
global ineqdata_natives = "Inequality"			// Data on Inequality 
global voladata_natives = "Volatility"			// Data on Volatility
global mobidata_natives = "Mobility"			// Data on Mobility

// Foreign-Born: Europe & Americas
global maindir_foreignwest ="$maindir/Country analysis/Fbwest"
global ineqdata_foreignwest = "Inequality"			// Data on Inequality 
global voladata_foreignwest = "Volatility"			// Data on Volatility
global mobidata_foreignwest = "Mobility"			// Data on Mobility

// Foreign-Born: Africa, Asia
global maindir_foreigneast ="$maindir/Country analysis/Fbnonwest"
global ineqdata_foreigneast = "Inequality"			// Data on Inequality 
global voladata_foreigneast = "Volatility"			// Data on Volatility
global mobidata_foreigneast = "Mobility"			// Data on Mobility

// Where the figures are going to be saved 
capture noisily mkdir "$maindir\Figs\mainmigration"
global outfolder="$maindir\Figs\mainmigration\"	
	
if "${migrants}" == "yes"{  

// Where the data is stored
global ineqdata = "$ineqdata_foreign"		// Data on Inequality 
global voladata = "$voladata_foreign"			// Data on Volatility
global mobidata = "$mobidata_foreign"			// Data on Mobility

// Read initialize and plotting code. Do not change myplots.do
do "do/0_Initialize.do"
do "$maindir/do/myplots_BF.do"		

// Define these variables for your dataset
global yrfirst = 1985 		// First year in the dataset 
global yrlast =  2016 		// Last year in the dataset
global Tcommon = ${yrfirst}	// number of years used for th plots

// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	
	global legesize =     "large"	
	   
// Cd to folder with out 
	cd "$maindir_foreign" // Cd to the folder containing the files
	
// Which section are we ploting 
	global figineq =  "yes"			// Inequality
	global figvol =   "yes"			// Volatility
	global figcoh =   "yes"			// Cohort Graphs
	global figquan =  "yes"			// Income growth heterogeneity 
	global figquan_split =  "no"	// Income growth heterogeneity - early and late sample periods
	global figmob =   "yes"			// Mobility

/*---------------------------------------------------	
    Inequality
 ---------------------------------------------------*/
if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "${outfolder}"	

	foreach subgp in male fem {		
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
		
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.3
		local y2 = 0.8
		local y3 = 0.1
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_mig_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
	   
// Figures 1B (normalized top percentiles)	 
	if "${vari}" == "logearn"{
		local y1 = 0
		local y2 = 1.4
		local y3 = 0.2
	}
	
	tspltAREALimPA "np99_99$vari np99_9$vari np99$vari np95$vari np90$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p99.99" "p99.9" "p99" "p95" "p90" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1B_mig_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "D + S x O" 

// Figure 2 (Inequality)	
	if "${vari}" == "logearn"{
		local y1 = 1.0
		local y2 = 2.4
		local y3 = 0.1
	}
		   		   
	tspltAREALimPA "sd$vari p9010$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "2.56*{&sigma}" "P90-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2A_mig_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	if "${vari}" == "logearn"{
		local y1 = 0.4
		local y2 = 1.6
		local y3 = 0.2
	} 
	if "${vari}" == "researn"{
		local y1 = 0.4
		local y2 = 1.4
		local y3 = 0.2
	}
	if "${vari}" == "researne" {
		local y1 = 0.4
		local y2 = 1.4
		local y3 = 0.2
	}
	 tspltAREALimPA "p9050$vari  p5010$vari " /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2B_mig_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 	  		
	   
	   }	// END of loop over subgroups
	}
}		// END

/*---------------------------------------------------	
    Inequality by education
 ---------------------------------------------------*/
if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "${outfolder}"	

	foreach subgp in male fem {		
	foreach subgp2 in low high {	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "male"{
	if "`subgp2'" == "low"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==1 & educ == 1	// Keep the group we want to plot 
		local labname = "High-Educated Men"
	}
		
	if "`subgp2'" == "high"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==1 & educ == 2	// Keep the group we want to plot 
		local labname = "Low-Educated Men"
	}
	}
	if "`subgp'" == "fem"{
	if "`subgp2'" == "low"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==0 & educ == 1	// Keep the group we want to plot 
		local labname = "High-Educated Women"
	}
		
	if "`subgp2'" == "high"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==0 & educ == 2	// Keep the group we want to plot 
		local labname = "Low-Educated Women"
	}
	}
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	
	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.3
		local y2 = 0.8
		local y3 = 0.1
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_mig_`subgp'_`subgp2'educ_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
	      
	   }	// END of loop over subgroups
	}
}		// END loop over variables

}	// END of inequality section
	
/*---------------------------------------------------	
    Volatility
 ---------------------------------------------------*/
if "${figvol}" == "yes"{  

/*---------------------------------------------------	
    Volatility by education
 ---------------------------------------------------*/
if "${figvol}" == "yes"{  


*Time series for slides 

	*Plot One-year changes
	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "researn`jj'F"
	
	*Figure 5	
	foreach subgp in men women {

	insheet using "out${sep}${voladata}${sep}L_${vari}_maleeduc_sumstat.csv", case clear
	
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}
		
	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari})  - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	keep year educ ksk${vari} cku${vari} skew${vari} kurt${vari} p9010${vari}
	reshape wide ksk${vari} cku${vari} skew${vari} kurt${vari} p9010${vari}, i(year) j(educ)
	gen rece = inlist(year,${receyears})
	
	if "${vari}" == "researn1F"{
		local ylimlo = -0.4
		local ylimup = 0.35
		local ylimdf = 0.1			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = -0.4
		local ylimup = 0.4
		local ylimdf = 0.1		
		replace year = year + 2		// This is to center the 5-year changes
	}

	
	 tspltAREALimPA "ksk${vari}1 ksk${vari}2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Low Educ" "High Educ" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_mig_`subgp'_byeduc_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	
   
	   }	// END loop jumps
	}
}
***

*Time series for slides 

	*Plot One-year changes
	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "researn`jj'F"
	
	*Figure 4
	foreach subgp in men women {
	
		if "${vari}" == "researn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			local labtitle = "g{sup:1}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
		}
		
		*Load data 				
		insheet using "out${sep}${voladata}${sep}L_${vari}_male_sumstat.csv", case clear
		
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}				

		gen rece = inlist(year,${receyears})
		
		gen p9050$vari = p90$vari - p50$vari
		gen p5010$vari = p50$vari - p10$vari
		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.2
			local ylimup = 0.7
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.3
			local ylimup = 1.2
			local ylimdf = 0.3	
			replace year = year + 2		// This is to center the 5-year changes
		}
		
		   tspltAREALimPA "p9050$vari  p5010$vari" /// Which variables?
		   "year" ///
		   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		   "Dispersion of `labtitle'" /// y axis title 
		   "" ///  Plot title
		   "" ///
		   "fig4_mig_`subgp'_${vari}"	/// Figure name
		   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
		   "" 						/// If legend is active or nor	
		   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
		   "O S" 

	}

	}
}
***

	/*----------------------------------------
	Cohorts and Initial Inequality
------------------------------------------*/
if "${figcoh}" == "yes"{ 

global folderfile = "${outfolder}"	
	
foreach var in logearn{	// Add here other variables 
	foreach subgp in male fem {			// Add here other groups 
	
	// Plots by cohorts 			
	*Which variable is under analysis? 
	*The code generates for raw earnimgs and residuals earnigs
	global vari = "`var'"		
	
	*Label for plots
	local labtitle = "log y{sub:it}"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
		
		*Age 25
		local posi1= 2.25
		local posi2= 2.16
		local posi3= 2.25
		
		local yposi1= 1992
		local yposi2= 1994
		local yposi3= 1992
		
		*Age 35
		local posj1= 1.7
		local posj2= 1.9
		local posj3= 1.7
		
		local yposj1= 1999
		local yposj2= 2001
		local yposj3= 1999
		
	}	
	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
		
		*Age 25
		local posi1= 2.15
		local posi2= 2.07
		local posi3= 2.2
		
		local yposi1= 1994
		local yposi2= 1996
		local yposi3= 1994
		
		*Age 35
		local posj1= 1.75
		local posj2= 1.92
		local posj3= 1.75
		
		local yposj1= 1996
		local yposj2= 1998
		local yposj3= 1996

	}
		
	*Calculate additional moments 
	gen p99990${vari} = p99_9${vari} - p99${vari}
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p9010${vari} = p90${vari} - p10${vari}	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
	
	

	gkswplot_co "p9010`var'" "year" ///
			 "1985 1993 2000 2010" /// what cohorts?
			 "25 35 45" /// What ages: code allows three
			 "1985" "2015" "5" /// x-axis
			 "on" "7" "2" "Cohort 1985" "Cohort 1993" "Cohort 2000" "Cohort 2010" /// Legends
			 "" "P90-P10 of Log Earnings"  /// x and y titles 
			 "" "large" "" "" ///
			 "0.75" "2.25" "0.5" ///
			 "fig3B_mig_`subgp'_${vari}" ///
			 "`posi1'" "`yposi1'" "`posi2'" "`yposi2'" "`posi3'" "`yposi3'" "25 yrs old" ///
			 "`posj1'" "`yposj1'" "`posj2'" "`yposj2'" "`posj3'" "`yposj3'" "35 yrs old" 

	
}	// END loop subgroups
}	// END loop over variables 
}	// END section cohorts


/*---------------------------------------------------	
    Income growth heterogeneity 
 ---------------------------------------------------*/	
 
 if "${figquan}" == "yes"{ 

	global folderfile = "${outfolder}"	
	
		foreach mm in 0 1 2{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
		*Load the data for the last percentile
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata}${sep}L_`var'_agerank.csv", clear case	    
		}
		
		drop if year < ${Tcommon}
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
				
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
			
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.5
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.2
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_mig_${vari}_`lname'.pdf", replace 

		}	// END loop variables		
		}	// END loop men/women	

		
		
		
		}
	

if "${figquan_split}" == "yes"{ 

	global folderfile = "${outfolder}"	
	
		foreach mm in  0 1 2{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
		*Load the data for the last percentile
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata}${sep}L_`var'_agerank.csv", clear case	    
		}
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
		
		gen time = 1 if year <=2004
		replace time = 2 if year >= 2005
		
		gen bin = permrank/2.5
		replace bin = ceil(bin/2)
		replace permrank = 5*bin
		
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(time agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(agegp permrank) j(time)		
		reshape wide p9010${vari}1 p9050${vari}1 p5010${vari}1 sd${vari}1 ksk${vari}1 skew${vari}1 cku${vari}1 kurt${vari}1 p9010${vari}2 p9050${vari}2 p5010${vari}2 sd${vari}2 ksk${vari}2 skew${vari}2 cku${vari}2 kurt${vari}2, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure A		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.0
			local ylimup = 2.2
			local ylimdf = 0.5			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.5
			local ylimup = 3
			local ylimdf = 0.5		
		}
		
		tw (connected p9010${vari}11 p9010${vari}12 p9010${vari}13 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))		
		graph export "${folderfile}/fig6A_mig_${vari}_`lname'_early.pdf", replace 

		tw (connected p9010${vari}21 p9010${vari}22 p9010${vari}23 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))		
		graph export "${folderfile}/fig6A_mig_${vari}_`lname'_late.pdf", replace 
		
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.5
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.2
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}11 ksk${vari}12 ksk${vari}13 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_mig_${vari}_`lname'_early.pdf", replace 

		tw (connected ksk${vari}21 ksk${vari}22 ksk${vari}23 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_mig_${vari}_`lname'_late.pdf", replace 
		
		*Figure C
		if "${vari}" == "researn1F"{
			local ylimlo = 1
			local ylimup = 15
			local ylimdf = 2
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 1
			local ylimup = 11
			local ylimdf = 2	
		}
		
		tw (connected cku${vari}11 cku${vari}12 cku${vari}13 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig6C_mig_${vari}_`lname'_early.pdf", replace 	
		
		tw (connected cku${vari}21 cku${vari}22 cku${vari}23 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig6C_mig_${vari}_`lname'_late.pdf", replace 

		}	// END loop variables		
		}	// END loop men/women	

		
		
		
		}
	
}

if "${natives}" == "yes"{ 
clear all
set more off

// Where the data is stored
global ineqdata = "$ineqdata_natives"			// Data on Inequality 
global voladata = "$voladata_natives"			// Data on Volatility
global mobidata = "$mobidata_natives"			// Data on Mobility

// Read initialize and plotting code. Do not change myplots.do
do "do/0_Initialize.do"	
do "$maindir/do/myplots_BF.do"		

// Define these variables for your dataset
global yrfirst = 1985 		// First year in the dataset 
global yrlast =  2016 		// Last year in the dataset
global Tcommon = ${yrfirst}	// number of years used for th plots

// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	
	global legesize =     "large"	
	   
// Cd to folder with out 
	cd "$maindir_natives" // Cd to the folder containing the files
	
// Which section are we ploting 
	global figineq =  "yes"			// Inequality
	global figvol =   "yes"			// Volatility
	global figquan =  "yes"			// Income growth heterogeneity 
	global figmob =   "no"			// Mobility

/*---------------------------------------------------	
    Inequality
 ---------------------------------------------------*/
if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "${outfolder}"	

	foreach subgp in male fem {		
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
		
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.3
		local y2 = 0.8
		local y3 = 0.1
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_nat_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
	   
// Figures 1B (normalized top percentiles)	 
	if "${vari}" == "logearn"{
		local y1 = 0
		local y2 = 1.4
		local y3 = 0.2
	}
	
	tspltAREALimPA "np99_99$vari np99_9$vari np99$vari np95$vari np90$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p99.99" "p99.9" "p99" "p95" "p90" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1B_nat_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "D + S x O" 

// Figure 2 (Inequality)	
	if "${vari}" == "logearn"{
		local y1 = 1.0
		local y2 = 2.4
		local y3 = 0.1
	}
		   		   
	tspltAREALimPA "sd$vari p9010$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "2.56*{&sigma}" "P90-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2A_nat_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	if "${vari}" == "logearn"{
		local y1 = 0.4
		local y2 = 1.6
		local y3 = 0.2
	} 
	if "${vari}" == "researn"{
		local y1 = 0.4
		local y2 = 1.4
		local y3 = 0.2
	}
	if "${vari}" == "researne" {
		local y1 = 0.4
		local y2 = 1.4
		local y3 = 0.2
	}
	 tspltAREALimPA "p9050$vari  p5010$vari " /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2B_nat_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 	  		
	   
	   }	// END of loop over subgroups
	}
}		// END

/*---------------------------------------------------	
    Inequality by education
 ---------------------------------------------------*/
if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "${outfolder}"	

	foreach subgp in male fem {		
	foreach subgp2 in low high {	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "male"{
	if "`subgp2'" == "low"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==1 & educ == 1	// Keep the group we want to plot 
		local labname = "High-Educated Men"
	}
		
	if "`subgp2'" == "high"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==1 & educ == 2	// Keep the group we want to plot 
		local labname = "Low-Educated Men"
	}
	}
	if "`subgp'" == "fem"{
	if "`subgp2'" == "low"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==0 & educ == 1	// Keep the group we want to plot 
		local labname = "High-Educated Women"
	}
		
	if "`subgp2'" == "high"{
		insheet using "out${sep}${ineqdata}${sep}L_`var'_maleeduc_sumstat.csv", clear
		keep if male==0 & educ == 2	// Keep the group we want to plot 
		local labname = "Low-Educated Women"
	}
	}
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	
	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.3
		local y2 = 0.8
		local y3 = 0.1
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_nat_`subgp'_`subgp2'educ_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
	   
   
	   }	// END of loop over subgroups
	}
}		// END loop over variables

}	// END of inequality section
	

/*---------------------------------------------------	
    Volatility
 ---------------------------------------------------*/
if "${figvol}" == "yes"{  


*Time series for slides 

	*Plot One-year changes
	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "researn`jj'F"
	
	*Figure 4
	foreach subgp in men women {
	
		if "${vari}" == "researn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			local labtitle = "g{sup:1}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
		}
		
		*Load data 				
		insheet using "out${sep}${voladata}${sep}L_${vari}_male_sumstat.csv", case clear
		
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}				

		gen rece = inlist(year,${receyears})
		
		gen p9050$vari = p90$vari - p50$vari
		gen p5010$vari = p50$vari - p10$vari
		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.2
			local ylimup = 0.7
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.3
			local ylimup = 1.2
			local ylimdf = 0.3	
			replace year = year + 2		// This is to center the 5-year changes
		}
		
		   tspltAREALimPA "p9050$vari  p5010$vari" /// Which variables?
		   "year" ///
		   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		   "Dispersion of `labtitle'" /// y axis title 
		   "" ///  Plot title
		   "" ///
		   "fig4_nat_`subgp'_${vari}"	/// Figure name
		   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
		   "" 						/// If legend is active or nor	
		   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
		   "O S" 

	}

	}
}
***

/*---------------------------------------------------	
    Volatility by education
 ---------------------------------------------------*/
if "${figvol}" == "yes"{  


*Time series for slides 

	*Plot One-year changes
	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "researn`jj'F"
	
	*Figure 5	
	foreach subgp in men women {

	insheet using "out${sep}${voladata}${sep}L_${vari}_maleeduc_sumstat.csv", case clear
	
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}
		
	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari})  - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	keep year educ ksk${vari} cku${vari} skew${vari} kurt${vari} p9010${vari}
	reshape wide ksk${vari} cku${vari} skew${vari} kurt${vari} p9010${vari}, i(year) j(educ)
	gen rece = inlist(year,${receyears})
	
	if "${vari}" == "researn1F"{
		local ylimlo = -0.4
		local ylimup = 0.35
		local ylimdf = 0.1			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = -0.4
		local ylimup = 0.4
		local ylimdf = 0.1		
		replace year = year + 2		// This is to center the 5-year changes
	}

	
	 tspltAREALimPA "ksk${vari}1 ksk${vari}2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Low Educ" "High Educ" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_nat_`subgp'_byeduc_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	
   
	   }	// END loop jumps
	}
}
***

/*---------------------------------------------------	
    Income growth heterogeneity 
 ---------------------------------------------------*/
  
if "${figquan}" == "yes"{ 

	global folderfile = "${outfolder}"	
	
		foreach mm in 0 1 2{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
		*Load the data for the last percentile
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata}${sep}L_`var'_agerank.csv", clear case	    
		}
		
		drop if year < ${Tcommon}
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
				
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure A		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.0
			local ylimup = 2.2
			local ylimdf = 0.5			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.5
			local ylimup = 3
			local ylimdf = 0.5		
		}
		
		tw (connected p9010${vari}1 p9010${vari}2 p9010${vari}3 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))		
		graph export "${folderfile}/fig6A_nat_${vari}_`lname'.pdf", replace 
			
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.5
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.2
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_nat_${vari}_`lname'.pdf", replace 
				
		*Figure C
		if "${vari}" == "researn1F"{
			local ylimlo = 1
			local ylimup = 15
			local ylimdf = 2
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 1
			local ylimup = 11
			local ylimdf = 2	
		}
		
		tw (connected cku${vari}1 cku${vari}2 cku${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig6C_nat_${vari}_`lname'.pdf", replace 	

		}	// END loop variables		
		}	// END loop men/women	

		
		
		
		}
	

if "${figquan_split}" == "yes"{ 

	global folderfile = "${outfolder}"	
	
		foreach mm in  0 1 2{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
		*Load the data for the last percentile
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata}${sep}L_`var'_agerank.csv", clear case	    
		}
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
		
		gen time = 1 if year <=2004
		replace time = 2 if year >= 2005
		gen bin = permrank/2.5
		replace bin = ceil(bin/2)
		replace permrank = 5*bin
		
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(time agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(agegp permrank) j(time)		
		reshape wide p9010${vari}1 p9050${vari}1 p5010${vari}1 sd${vari}1 ksk${vari}1 skew${vari}1 cku${vari}1 kurt${vari}1 p9010${vari}2 p9050${vari}2 p5010${vari}2 sd${vari}2 ksk${vari}2 skew${vari}2 cku${vari}2 kurt${vari}2, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure A		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.0
			local ylimup = 2.2
			local ylimdf = 0.5			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.5
			local ylimup = 3
			local ylimdf = 0.5		
		}
		
		tw (connected p9010${vari}11 p9010${vari}12 p9010${vari}13 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))		
		graph export "${folderfile}/fig6A_${vari}_`lname'_early.pdf", replace 

		tw (connected p9010${vari}21 p9010${vari}22 p9010${vari}23 permrank if idex<=42, msymbol(none none o)  ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10 Differential of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))		
		graph export "${folderfile}/fig6A_${vari}_`lname'_late.pdf", replace 
		
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.5
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.2
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}11 ksk${vari}12 ksk${vari}13 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_${vari}_`lname'_early.pdf", replace 

		tw (connected ksk${vari}21 ksk${vari}22 ksk${vari}23 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_${vari}_`lname'_late.pdf", replace 
		
		*Figure C
		if "${vari}" == "researn1F"{
			local ylimlo = 1
			local ylimup = 15
			local ylimdf = 2
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 1
			local ylimup = 11
			local ylimdf = 2	
		}
		
		tw (connected cku${vari}11 cku${vari}12 cku${vari}13 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig6C_${vari}_`lname'_early.pdf", replace 	
		
		tw (connected cku${vari}21 cku${vari}22 cku${vari}23 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(medium)) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig6C_${vari}_`lname'_late.pdf", replace 

		}	// END loop variables		
		}	// END loop men/women	

		
		}
	
}

if "${byorigin}" == "yes"{ 
clear all

cd "$maindir_foreign"


// Read initialize and plotting code. Do not change myplots.do
do "do/0_Initialize.do"	
do "$maindir/do/myplots_BF.do"		

// Define these variables for your dataset
global yrfirst = 1985 		// First year in the dataset 
global yrlast =  2016 		// Last year in the dataset

// Define some common charactristics of the plots 
	global xtitlesize =   "large" 
	global ytitlesize =   "large" 
	global xlabsize =     "large" 
	global ylabsize =     "large" 
	global titlesize  =   "large" 
	global subtitlesize = "medium" 
	global formatfile  =  "pdf"
	global fontface   =   "Times New Roman"
	global marksize =     "medium"	
	global legesize =     "large"	

global maindir1 $maindir_foreign

// Where the data is stored
global ineqdata1 = "$ineqdata_foreign"			// Data on Inequality 
global voladata1 = "$voladata_foreign"			// Data on Volatility
global mobidata1 = "$mobidata_foreign"			// Data on Mobility

global maindir2 $maindir_natives

// Where the data is stored
global ineqdata2 = "$ineqdata_natives"			// Data on Inequality 
global voladata2 = "$voladata_natives"			// Data on Volatility
global mobidata2 = "$mobidata_natives"			// Data on Mobility

******************************************
*** Inequality by Origin
******************************************
	foreach subgp in male fem {		
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	cd "$maindir1"
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata1}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata1}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
		
	*Percentile Gaps 
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}

	keep year p9050${vari} p5010${vari} 
    rename p9050${vari} p9050_1 
    rename p5010${vari} p5010_1 

	cd "$maindir2"
	save tempdata, replace
	
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata2}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata2}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}

	keep year p9050${vari} p5010${vari} 
    rename p9050${vari} p9050_2 
    rename p5010${vari} p5010_2 	
	
	keep year p9050_2 p5010_2 
	
	merge 1:1 year using tempdata, keep(match)
	drop _merge	
	
		*Generate recession vars
	gen rece = inlist(year,${receyears})
	
// Figure 2 (Inequality)
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	
	if "${vari}" == "logearn"{
		local y1 = 0
		local y2 = 1.6
		local y3 = 0.2
	} 
	if "${vari}" == "researn"{
		local y1 = 0
		local y2 = 1.4
		local y3 = 0.2
	}
	if "${vari}" == "researne" {
		local y1 = 0
		local y2 = 1.4
		local y3 = 0.2
	}
	 tspltAREALimPA "p9050_1 p9050_2 p5010_1 p5010_2 " /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50, Foreign" "P90-P50, Native" "P50-P10, Foreign" "P50-P10, Native" "" "" "" "" "" /// Labels 
	   "2" "7" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2B_`subgp'_byorigin_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue navy red maroon red forest_green purple gray orange"			/// Colors
	   "O S D T" 	  		
	   
	   }	// END of loop over subgroups
	}

******************************************
*** Volatility by Origin
******************************************
	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "researn`jj'F"
	
foreach subgp in male fem {

	cd "$maindir1" 
	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata1}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata1}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	keep year p9010${vari} ksk${vari} cku${vari} skew${vari} kurt${vari}
    rename p9010${vari} p9010_1 
    rename ksk${vari} ksk_1 
    rename cku${vari} cku_1 
    rename skew${vari} skew_1 
	rename kurt${vari} kurt_1 

	cd "$maindir2"
	save tempdata, replace

	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata2}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata2}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}

	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
    rename p9010${vari} p9010_2 	
    rename ksk${vari} ksk_2 
    rename cku${vari} cku_2 
    rename skew${vari} skew_2 
	rename kurt${vari} kurt_2 
	
	keep year p9010_2 ksk_2 cku_2 skew_2 kurt_2 
	
	merge 1:1 year using tempdata, keep(match)
	drop _merge	
	
		if "${vari}" == "researn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			local labtitle = "g{sup:1}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
		}
	gen rece = inlist(year,${receyears})
	
	if "${vari}" == "researn1F"{
		local ylimlo = 0.3
		local ylimup = 1.5
		local ylimdf = 0.3			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = 0.6
		local ylimup = 2.0
		local ylimdf = 0.2		
		replace year = year + 2		// This is to center the 5-year changes
	}

	tspltAREALimPA "p9010_1 p9010_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign-Born" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "P90-P10 of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig4B_`subgp'_byorigin_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S"
	   
	if "${vari}" == "researn1F"{
		local ylimlo = -0.4
		local ylimup = 0.35
		local ylimdf = 0.1			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = -0.4
		local ylimup = 0.4
		local ylimdf = 0.1		
		replace year = year + 2		// This is to center the 5-year changes
	}

	
	 tspltAREALimPA "ksk_1 ksk_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_`subgp'_byorigin_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	

	if "${vari}" == "researn1F"{
		local ylimlo = -2.0
		local ylimup = 0
		local ylimdf = 0.5			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = -2.5
		local ylimup = -0.5
		local ylimdf = 0.5			
		replace year = year + 2		// This is to center the 5-year changes
	}
	 tspltAREALimPA "skew_1 skew_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5C_`subgp'_byorigin_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	   
	   
	if "${vari}" == "researn1F"{
		local ylimlo = 6
		local ylimup = 14
		local ylimdf = 1	
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = 3
		local ylimup = 8
		local ylimdf = 1			
	}
 	 
	 tspltAREALimPA "cku_1 cku_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5B_`subgp'_byorigin_${vari}"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 

	   if "${vari}" == "researn1F"{
		local ylimlo = 8
		local ylimup = 20
		local ylimdf = 2	
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = 5
		local ylimup = 13
		local ylimdf = 2			
	}
	   tspltAREALimPA "kurt_1 kurt_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5D_`subgp'_byorigin_${vari}"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 	   
	   }	// END loop jumps
}

******************************************
*** Volatility by Origin: Arc-Pct Change
******************************************
	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "arcearn`jj'F"
	
foreach subgp in male fem {

	cd "$maindir1" 
	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata1}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata1}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	keep year p9010${vari} ksk${vari} cku${vari} skew${vari} kurt${vari}
    rename p9010${vari} p9010_1 
    rename ksk${vari} ksk_1 
    rename cku${vari} cku_1 
    rename skew${vari} skew_1 
	rename kurt${vari} kurt_1 

	cd "$maindir2"
	save tempdata, replace

	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata2}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata2}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}

	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
    rename p9010${vari} p9010_2 	
    rename ksk${vari} ksk_2 
    rename cku${vari} cku_2 
    rename skew${vari} skew_2 
	rename kurt${vari} kurt_2 
	
	keep year p9010_2 ksk_2 cku_2 skew_2 kurt_2 
	
	merge 1:1 year using tempdata, keep(match)
	drop _merge	
	
		if "${vari}" == "arcearn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			local labtitle = "arc{sup:1}{sub:it}"
		}		
		if "${vari}" == "arcearn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "arc{sup:5}{sub:it}" // ?? what labels here?
		}
	gen rece = inlist(year,${receyears})
	
	if "${vari}" == "arcearn1F"{
		local ylimlo = 0.3
		local ylimup = 1.5
		local ylimdf = 0.3				
	}		
	if "${vari}" == "arcearn5F"{
		local ylimlo = 0.6
		local ylimup = 2.0
		local ylimdf = 0.2		
		replace year = year + 2		// This is to center the 5-year changes
	}

	tspltAREALimPA "p9010_1 p9010_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign-Born" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "P90-P10 of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig4B_`subgp'_byorigin_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S"
	   
	if "${vari}" == "arcearn1F"{
		local ylimlo = -0.4
		local ylimup = 0.7
		local ylimdf = 0.2			
	}		
	if "${vari}" == "arcearn5F"{
		local ylimlo = -0.4
		local ylimup = 0.4
		local ylimdf = 0.1		
		replace year = year + 2		// This is to center the 5-year changes
	}

	
	 tspltAREALimPA "ksk_1 ksk_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_`subgp'_byorigin_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	

	if "${vari}" == "arcearn1F"{
		local ylimlo = -1
		local ylimup = 0.5
		local ylimdf = 0.5			
	}		
	if "${vari}" == "arcearn5F"{
		local ylimlo = -2.5
		local ylimup = -0.5
		local ylimdf = 0.5			
		replace year = year + 2		// This is to center the 5-year changes
	}
	 tspltAREALimPA "skew_1 skew_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5C_`subgp'_byorigin_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	   
	   
	if "${vari}" == "arcearn1F"{
		local ylimlo = 3
		local ylimup = 20
		local ylimdf = 3	
	}		
	if "${vari}" == "arcearn5F"{
		local ylimlo = 3
		local ylimup = 8
		local ylimdf = 1			
	}
 	 
	 tspltAREALimPA "cku_1 cku_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5B_`subgp'_byorigin_${vari}"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 

	   if "${vari}" == "arcearn1F"{
		local ylimlo = 2
		local ylimup = 12
		local ylimdf = 2	
	}		
	if "${vari}" == "arcearn5F"{
		local ylimlo = 5
		local ylimup = 13
		local ylimdf = 2			
	}
	   tspltAREALimPA "kurt_1 kurt_2" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign" "Native" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5D_`subgp'_byorigin_${vari}"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 	   
	   }	// END loop jumps
}

}

if "${migrantsbyregion}" == "yes"{ 
	
*** Compare immigrants from different regions of the world:

global maindir3 $maindir_foreignwest

// Where the data is stored
global ineqdata3 = "$ineqdata_foreignwest"			// Data on Inequality 
global voladata3 = "$voladata_foreignwest"			// Data on Volatility
global mobidata3 = "$mobidata_foreignwest"			// Data on Mobility

global maindir4 $maindir_foreigneast

// Where the data is stored
global ineqdata4 = "$ineqdata_foreigneast"			// Data on Inequality 
global voladata4 = "$voladata_foreigneast"			// Data on Volatility
global mobidata4 = "$mobidata_foreigneast"			// Data on Mobility


// Which section are we ploting 
	global figineq =  "yes"			// Inequality
	global figvol =   "yes"			// Volatility
	global figquan =  "yes"			// Income growth heterogeneity 
	global figmob =   "no"			// Mobility
	
/*---------------------------------------------------	
    Inequality: Europe and Americas
 ---------------------------------------------------*/
if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "${outfolder}"	
	cd "$maindir3"
	foreach subgp in all male fem {		
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "all"{
		insheet using "out${sep}${ineqdata3}${sep}L_`var'_sumstat.csv", clear
		local labname = "All"
	}
	
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata3}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata3}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
		
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.3
		local y2 = 0.9
		local y3 = 0.1
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_euam_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
  		
	   
	   }	// END of loop over subgroups
	}
}		// END

/*---------------------------------------------------	
    Inequality: Africa, Asia, Middle East
 ---------------------------------------------------*/
if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	global folderfile = "${outfolder}"	
	cd "$maindir4"
	foreach subgp in all male fem {		
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "all"{
		insheet using "out${sep}${ineqdata4}${sep}L_`var'_sumstat.csv", clear
		local labname = "All"
	}
	
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata4}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata4}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
		
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}

	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari}{
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.3
		local y2 = 0.9
		local y3 = 0.1
	}
	
	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_aame_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
  		
	   
	   }	// END of loop over subgroups
	}
}		// END

/*---------------------------------------------------	
    Income growth heterogeneity: Europe and Americas 
 ---------------------------------------------------*/	
 cd "$maindir3"
if "${figquan}" == "yes"{ 

	global folderfile = "${outfolder}"	
	
		foreach mm in  2{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
		*Load the data for the last percentile
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata3}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata3}${sep}L_`var'_agerank.csv", clear case	    
		}
		
		drop if year < ${Tcommon}
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
		
		gen bin = permrank/2.5
		replace bin = ceil(bin/2)
		replace permrank = 5*bin
		
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
	
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.5
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.2
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_euam_${vari}_`lname'.pdf", replace 
	

		}	// END loop variables		
		}	// END loop men/women	

		
		
		
		}
	
/*---------------------------------------------------	
    Income growth heterogeneity: Africa, Asia, Middle East
 ---------------------------------------------------*/	
 cd "$maindir4"
if "${figquan}" == "yes"{ 

	global folderfile = "${outfolder}"	
	
		foreach mm in  2{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		global vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "g{sup:1}{sub:it}"
		}
		if "${vari}" == "researn5F"{
			local labtitle = "g{sup:5}{sub:it}"
		}
	 
		*Load the data for the last percentile
		if  `mm'==0 | `mm'==1 {
		insheet using "out${sep}${voladata4}${sep}L_`var'_maleagerank.csv", clear case
		}
		if `mm' == 2 {
		insheet using "out${sep}${voladata4}${sep}L_`var'_agerank.csv", clear case	    
		}
		
		drop if year < ${Tcommon}
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		else if `mm' == 2{
			local lname = "all"
			local mlabel = "All"		    
		}
		
		gen bin = permrank/2.5
		replace bin = ceil(bin/2)
		replace permrank = 5*bin
		
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
	
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.5
			local ylimup = 0.25
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.2
			local ylimdf = 0.1		
		}
		
		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, msymbol(none none o) ///
		color(red blue green) lpattern(solid dash dash_dot) lwidth(thick thick thick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of Permanent Income P{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness of `labtitle'", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig6B_aame_${vari}_`lname'.pdf", replace 

		}	// END loop variables		
		}	// END loop men/women	

		
		
		
		}
	
/*---------------------------------------------------	
    Inequality: Foreign-Born by Region
 ---------------------------------------------------*/
	foreach subgp in male fem {		
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researne researn"			
	}	
	else {
		local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	cd "$maindir3"
	*What is the group under analysis? 
	*You can add more groups to this section
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata3}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata3}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
		
	*Percentile Gaps 
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}

	keep year p9050${vari} p5010${vari} 
    rename p9050${vari} p9050_1 
    rename p5010${vari} p5010_1 

	cd "$maindir4"
	save tempdata, replace
	
	if "`subgp'" == "male"{
		insheet using "out${sep}${ineqdata4}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${ineqdata4}${sep}L_`var'_male_sumstat.csv", clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}

	keep year p9050${vari} p5010${vari} 
    rename p9050${vari} p9050_2 
    rename p5010${vari} p5010_2 	
	
	keep year p9050_2 p5010_2 
	
	merge 1:1 year using tempdata, keep(match)
	drop _merge	
	
		*Generate recession vars
	gen rece = inlist(year,${receyears})
	
// Figure 2 (Inequality)
	
	*What is the label for title 
	if "${vari}" == "logearn"{
		local labtitle = "Log Earnings"
// 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" | "${vari}" == "researne"{
		local labtitle = "Residual Log Earnings"
// 		local labtitle = "{&epsilon}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" | "${vari}" == "researne" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	
	if "${vari}" == "logearn"{
		local y1 = 0
		local y2 = 1.6
		local y3 = 0.2
	} 
	if "${vari}" == "researn"{
		local y1 = 0
		local y2 = 1.4
		local y3 = 0.2
	}
	if "${vari}" == "researne" {
		local y1 = 0
		local y2 = 1.4
		local y3 = 0.2
	}
	 tspltAREALimPA "p9050_1 p9050_2 p5010_1 p5010_2 " /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50, EUAM" "P90-P50, AAME" "P50-P10, EUAM" "P50-P10, AAME" "" "" "" "" "" /// Labels 
	   "2" "7" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2B_`subgp'_byregion_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue navy red maroon red forest_green purple gray orange"			/// Colors
	   "O S D T" 	  		
	   
	   }	// END of loop over subgroups
	}

}

if "${byoriginregion}" == "yes"{ 

*** Combine all four samples:

global maindir1 $maindir_foreign

// Where the data is stored
global ineqdata1 = "$ineqdata_foreign"			// Data on Inequality 
global voladata1 = "$voladata_foreign"			// Data on Volatility
global mobidata1 = "$mobidata_foreign"			// Data on Mobility

global maindir2 $maindir_natives

// Where the data is stored
global ineqdata2 = "$ineqdata_natives"			// Data on Inequality 
global voladata2 = "$voladata_natives"			// Data on Volatility
global mobidata2 = "$mobidata_natives"			// Data on Mobility

global maindir3 $maindir_foreignwest

// Where the data is stored
global ineqdata3 = "$ineqdata_foreignwest"			// Data on Inequality 
global voladata3 = "$voladata_foreignwest"			// Data on Volatility
global mobidata3 = "$mobidata_foreignwest"			// Data on Mobility

global maindir4 $maindir_foreigneast

// Where the data is stored
global ineqdata4 = "$ineqdata_foreigneast"			// Data on Inequality 
global voladata4 = "$voladata_foreigneast"			// Data on Volatility
global mobidata4 = "$mobidata_foreigneast"			// Data on Mobility

	foreach jj in 1 5{ 
		
	global folderfile = "${outfolder}"	
	global vari = "researn`jj'F"
	
foreach subgp in male fem {

	cd "$maindir1" 
	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata1}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata1}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}
	
	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	keep year p9010${vari} ksk${vari} cku${vari} skew${vari} kurt${vari}
    rename p9010${vari} p9010_1 
    rename ksk${vari} ksk_1 
    rename cku${vari} cku_1 
    rename skew${vari} skew_1 
	rename kurt${vari} kurt_1 

	cd "$maindir4"
	save tempdata1, replace
	
	cd "$maindir2"
	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata2}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata2}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}

	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
    rename p9010${vari} p9010_2 	
    rename ksk${vari} ksk_2 
    rename cku${vari} cku_2 
    rename skew${vari} skew_2 
	rename kurt${vari} kurt_2 
	
	keep year p9010_2 ksk_2 cku_2 skew_2 kurt_2 
	
	cd "$maindir4"
	save tempdata2, replace	
	
	cd "$maindir3"
	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata3}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata3}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}

	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
    rename p9010${vari} p9010_3 	
    rename ksk${vari} ksk_3 
    rename cku${vari} cku_3 
    rename skew${vari} skew_3 
	rename kurt${vari} kurt_3 
	
	keep year p9010_3 ksk_3 cku_3 skew_3 kurt_3 
	
	cd "$maindir4"
	save tempdata3, replace		
	
	if "`subgp'" == "male"{
		insheet using "out${sep}${voladata4}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "fem"{
		insheet using "out${sep}${voladata4}${sep}L_${vari}_male_sumstat.csv", case clear
		keep if male==0	// Keep the group we want to plot 
		local labname = "Women"
	}

	gen p9010${vari} = p90${vari} - p10${vari}
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari} ) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
    rename p9010${vari} p9010_4 	
    rename ksk${vari} ksk_4 
    rename cku${vari} cku_4 
    rename skew${vari} skew_4 
	rename kurt${vari} kurt_4 
	
	keep year p9010_4 ksk_4 cku_4 skew_4 kurt_4 	
	

	merge 1:1 year using tempdata1, keep(match)
	drop _merge	
	merge 1:1 year using tempdata2, keep(match)
	drop _merge	
	merge 1:1 year using tempdata3, keep(match)
	drop _merge	
	
		if "${vari}" == "researn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			local labtitle = "g{sup:1}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 2
			local ryear = ${yrlast} - 3	
			local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
		}
	gen rece = inlist(year,${receyears})
	
	if "${vari}" == "researn1F"{
		local ylimlo = 0
		local ylimup = 1.8
		local ylimdf = 0.3			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = 0.3
		local ylimup = 2.5
		local ylimdf = 0.3		
		replace year = year + 2		// This is to center the 5-year changes
	}

	tspltAREALimPA "p9010_1 p9010_2 p9010_3 p9010_4" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign-Born" "Native" "Europe & Americas" "Africa & Asia" "" "" "" "" "" /// Labels 
	   "2" "7" ///
	   "" /// x axis title
	   "P90-P10 of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig4B_`subgp'_byoriginregion_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue maroon navy forest_green blue purple gray orange"			/// Colors
	   "O S D T"
	   
	if "${vari}" == "researn1F"{
		local ylimlo = -0.4
		local ylimup = 0.35
		local ylimdf = 0.1			
	}		
	if "${vari}" == "researn5F"{
		local ylimlo = -0.4
		local ylimup = 0.4
		local ylimdf = 0.1		
	}

	 tspltAREALimPA "ksk_1 ksk_2 ksk_3 ksk_4" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Foreign-Born" "Native" "Europe & Americas" "Africa & Asia" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Kelley Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_`subgp'_byoriginregion_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue maroon navy maroon forest_green purple gray orange"		/// Colors
	   "O S D T" "yes"	

	   }	// END loop jumps
}


}
