**************************************************************************
* Program name: "Clean data.do" written 5 May 2019
* Set directory
cd "P:\2019\66\Use"
* STATA settings:
clear all
set more off
**************************************************************************

*********************
* 1. Clean dod data *
*********************

use "P:\2019\66\K1\dod8604.dta", clear
keep if feldod==0
gen dod_year=year(doddm)
keep dnr dod_year
save dod_year_8604, replace

use "P:\2019\66\K1\dod0507.dta", clear
gen dod_year=year(doddatum)
keep dnr dod_year
save dod_year_0507, replace

use "P:\2019\66\K1\dod0814.dta", clear
gen dod_year=year(doddatum)
keep dnr dod_year
save dod_year_0814, replace

use "P:\2019\66\K1\dod1516.dta", clear
gen dod_year=year(doddatum)
keep dnr dod_year
save dod_year_1516, replace

use "P:\2019\66\K1\dod17.dta", clear
gen dod_year=year(doddatum)
keep dnr dod_year
save dod_year_17, replace

use dod_year_8604, clear
foreach var in 0507 0814 1516 17{
append using dod_year_`var'
}
save dod_year_8617, replace

****************************
*** 2. Clean LOUISE data ***
****************************

*** 1985-1989 ***
forvalues I=1985/1989{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink fink{
cap destring `var', replace
}
cap rename syss85 syss

* Education *
gen hsunall=substr(hsun,2,1)
drop hsun
destring hsunall, replace
replace hsunall=. if hsunall==0

* Label variables *
label var dnr201966 "Person id"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var hsunall "Education level fine"
label var loneink "Labour income"
label var fink "Self-employment income"

compress
order dnr201966 year kon fodar hsunall loneink fink
sort dnr201966
save louisesys`I', replace
}

*** 1990-1997 ***
forvalues I=1990/1997{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink fink{
cap destring `var', replace
}

* Education *
gen hsunall=substr(hsun,-4,1)
drop hsun
destring hsunall, replace
replace hsunall=. if hsunall==0

* Label variables *
label var dnr201966 "Person id"
label var dnr201966familid1 "Family id 1"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var hsunall "Education level fine"
label var loneink "Labour income"
label var fink "Self-employment income"

compress
order dnr201966 dnr201966familid1 year kon fodar hsunall ///
loneink fink
sort dnr201966
save louisesys`I', replace
}

*** 1998 ***
forvalues I=1998/1998{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink fink{
cap destring `var', replace
}

* Education *
gen hsunall=substr(hsun,-4,1)
drop hsun
destring hsunall, replace
replace hsunall=. if hsunall==0

* Label variables *
label var dnr201966 "Person id"
label var dnr201966familid1 "Family id 1"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var loneink "Labour income"
label var fink "Self-employment income"
label var hsunall "Education level fine"

compress
order dnr201966 dnr201966familid1 year kon fodar hsunall ///
loneink fink
sort dnr201966
save louisesys`I', replace
}

*** 1999 ***
forvalues I=1999/1999{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink fink{
cap destring `var', replace
}

* Education *
gen hsunall=substr(hsun,-4,1)
drop hsun
destring hsunall, replace
replace hsunall=. if hsunall==0

* Label variables *
label var dnr201966 "Person id"
label var dnr201966familid1 "Family id 1"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var hsunall "Education level fine"
label var loneink "Labour income"
label var fink "Self-employment income"

compress
order dnr201966 dnr201966familid1 year kon fodar hsunall ///
loneink fink
sort dnr201966
save louisesys`I', replace
}

*** 2000-2003 ***
forvalues I=2000/2003{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink fink{
cap destring `var', replace
}

* Education *
rename hsun2no hsunall
destring hsunall, replace
replace hsunall=. if hsunall==9
cap drop hsun2n
cap drop hsun2i

* Label variables *
label var dnr201966 "Person id"
label var dnr201966familid1 "Family id 1"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var hsunall "Education level fine"
label var loneink "Labour income"
label var fink "Self-employment income"

compress
order dnr201966 dnr201966familid1 year kon fodar hsunall ///
loneink fink
sort dnr201966
save louisesys`I', replace
}

*** 2004-2015 ***
forvalues I=2004/2015{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink inkfnett*{
cap destring `var', replace
}

* Education *
rename hsun2no hsunall
destring hsunall, replace
replace hsunall=. if hsunall==9
cap drop hsun2n
cap drop hsun2i

* Label variables *
label var dnr201966 "Person id"
label var dnr201966familid1 "Family id 1"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var hsunall "Education level fine"
label var loneink "Labour income"
label var inkfnetta "Self-employment income"

compress
order dnr201966 dnr201966familid1 year kon fodar hsunall ///
loneink inkfnetta
sort dnr201966
save louisesys`I', replace
}

*** 2016 ***
forvalues I=2016/2016{
use "P:\2019\66\Leverans\louisesys`I'.dta", clear
duplicates drop
isid dnr201966
gen year=`I'

* Destring and rename variables *
foreach var in kon fodar loneink inkfnett*{
cap destring `var', replace
}

* Education *
rename hsun2no hsunall
destring hsunall, replace
replace hsunall=. if hsunall==9
cap drop hsun2n
cap drop hsun2i

* Label variables *
label var dnr201966 "Person id"
label var dnr201966familid1 "Family id 1"
label var year "Year"
label var kon "Gender"
label var fodar "Birth year"
label var hsunall "Education level fine"
label var loneink "Labour income"
label var inkfnetta "Self-employment income"

compress
order dnr201966 dnr201966familid1 year kon fodar hsunall ///
loneink inkfnetta
sort dnr201966
save louisesys`I', replace
}

*******************************
*** 2. Create long data set ***
*******************************

use dnr201966 year kon fodar hsunall loneink ///
fink using louisesys1985, clear
forvalues I=1986/1989{
append using louisesys`I', keep(dnr201966 ///
year kon fodar hsunall loneink fink)
}
forvalues I=1990/2003{
append using louisesys`I', keep(dnr201966 ///
year kon fodar hsunall loneink fink civil famtyp1 ///
dnr201966familid1 famstf barn*)
}
forvalues I=2004/2011{
append using louisesys`I', keep(dnr201966 ///
year kon fodar hsunall loneink inkfnetta civil famtyp1 ///
dnr201966familid1 famstf barn*)
}
forvalues I=2012/2016{
append using louisesys`I', keep(dnr201966 ///
year kon fodar hsunall loneink inkfnetta civil famtypf ///
dnr201966familid1 famstf barn*)
}

* Create a consistent birth year variable *
bys dnr201966: egen modefodar=mode(fodar), maxmode
replace fodar=modefodar
drop modefodar
gen age=year-fodar
label var age "Age"

* Create a consistent sex variable *
bys dnr201966: egen modekon=mode(kon), maxmode
replace kon=modekon
drop modekon
gen male=kon==1
label var male "Male"
drop kon

* Create max education measure *
replace hsunall=. if hsunall==8 | hsunall==9
bys dnr201966: egen maxhedu=max(hsunall)
label var maxhedu "Max education level achieved"
replace maxhedu=1 if maxhedu==.

* Create our education measure, "educ" *
recode maxhedu (1/4=1) (5/7=2), gen(educ)
label var educ "1 if less than college, 2 if some college"
drop maxhedu hsunall

* Create self-employment income *
gen selfinc=fink
replace selfinc=inkfnetta if selfinc==.
replace selfinc=0 if selfinc<0
replace selfinc=0 if selfinc==.
drop fink
label var selfinc "Self-employment income"
label var inkfnetta "Self-employment income, also negative values"

* Create labor income *
rename loneink labinc
label var labinc "Labor income"

* Create total earnings *
gen totinc=labinc+selfinc
label var totinc "Total labor income"

* Deflate earnings measures *
sort year
merge m:1 year using cpi, keep(master match)
drop _merge
replace cpi=cpi/328.4
gen totincreal=round(totinc/cpi)
gen labincreal=round(labinc/cpi)
gen selfincreal=round(selfinc/cpi)
gen inkfnettareal=round(inkfnetta/cpi)
label var totincreal "Real total labor income"
label var labincreal "Real labor income"
label var selfincreal "Real self-emp income"
label var inkfnettareal "Real self-emp income incl neg values"
label var cpi "CPI"

* Specify earnings measures in SEK *
foreach var in totincreal labincreal selfincreal inkfnettareal ///
totinc labinc selfinc inkfnetta{
replace `var'=`var'*100
}

* Sample restrictions *
keep if age>=20 & age<=64

* Create death year *
bys dnr201966: egen dodarl=max(year)
replace dodarl=. if dodarl==2016
replace dodarl=. if dodarl-fodar>=64
label var dodarl "Death year LOUISE"

merge m:1 dnr201966 using dod_year_8617, keep(master match)
drop _merge
label var dod_year "Death year death register"

* Family type *
gen famtyp=famtyp1
replace famtyp=famtypf if famtyp==""
replace famtyp="50" if famtyp=="00"
drop famtyp1 famtypf
destring famtyp, replace

gen familytype="married no children" if famtyp==11
replace familytype="married w children" if famtyp==12 | famtyp==13
replace familytype="cohab w children" if famtyp==21 | famtyp==22 | famtyp==23
replace familytype="single parent" if famtyp==31 | famtyp==32 | famtyp==41 | ///
famtyp==42
replace familytype="single" if famtyp==50
label var familytype "Family type"

* Family stallning *
foreach var in 11 12 13 14 15 16 21 22 23 24 40{
replace famstf="`var'0" if famstf=="`var'"
}
replace famstf="400" if famstf=="" | famstf=="000"
replace famstf="220" if famstf=="221"
destring famstf, replace

gen marital="married" if famstf==110 | famstf==120 | famstf==150 | famstf==160
replace marital="cohab" if famstf==130 | famstf==140
replace marital="single parent" if famstf==210 | famstf==220 | ///
famstf==230 | famstf==240
replace marital="single" if famstf>=311
label var marital "Marital status"

* Children *
egen children=rowtotal(barn0003 barn0406 barn0710 barn1115 barn1617 barn18pl ///
barn1819 barn20pl)
label var children "No children all ages"

* Summary measure family status *
gen famstatus="married no children" if familytype=="married no children" & ///
marital=="married"
replace famstatus="married w children" if familytype=="married w children" & ///
marital=="married"
replace famstatus="cohab w children" if familytype=="cohab w children" & ///
marital=="cohab"
replace famstatus="single parent" if familytype=="single parent" & ///
marital=="single parent"
replace famstatus="single" if marital=="single"
label var famstatus "Family status"

* xtset data *
destring dnr201966, gen(persid)
xtset persid year

* Order, sort and compress *
order dnr201966 persid year age male educ fodar ///
totincreal labincreal selfincreal
sort persid year
compress

save louise8516, replace

*******************
*** Add flergen ***
*******************

use "P:\2019\66\Leverans\flergen2017.dta", clear
keep dnr201966m fodelsear
rename dnr201966m dnr201966
save children_mothers, replace

use "P:\2019\66\Leverans\flergen2017.dta", clear
keep dnr201966f fodelsear
rename dnr201966f dnr201966
save children_fathers, replace

use children_mothers, clear
append using children_fathers
drop if dnr201966==""
order dnr fodelsear
sort dnr fodelsear
bys dnr (fodelsear): gen child=_n
reshape wide fodelsear, i(dnr201966) j(child)
expand 32
bys dnr: gen year=1984+_n
forvalues I=1/23{
gen child`I'=(fodelsear`I'<=year)
}
egen no_children=rowtotal(child1 child2 child3 child4 child5 child6 ///
child7 child8 child9 child10 child11 child12 child13 child14 child15 ///
child16 child17 child18 child19 child20 child21 child22 child23)
order dnr year no_children
save children_parents, replace

************************
*** Add foreign born ***
************************

use "P:\2019\66\K1\flnd9902.dta", clear
forvalues I=3/9{
append using "P:\2019\66\K1\flnd0`I'.dta"
}
forvalues I=10/11{
append using "P:\2019\66\K1\flnd`I'.dta"
}
duplicates drop
replace fland=fland2 if fland2!=""
drop fland2
replace fland="14" if fland=="15"
replace fland="14" if fland=="16"
replace fland="12" if fland=="11"
replace fland="01" if fland=="02"
duplicates drop
save fland99_11, replace

use "P:\2019\66\K1\fodelseuppgifter_2017.dta", clear
merge 1:m dnr201966 using fland99_11
destring flandgrp, replace
destring fland, replace
replace fland=. if fland<=25
replace flandgrp=fland if flandgrp==.
replace flandgrp=fland if flandgrp==53 & fland!=.
drop fland _merge
duplicates drop
sort dnr201966 flandgrp
duplicates drop dnr201966, force
drop dup
sort dnr201966
save fland_combined, replace

use louise8516, clear
merge m:1 dnr201966 using fland_combined, keep(master match)
drop _merge
gen foreignb=flandgrp!=.
label var flandgrp "Birth country"
label var foreignb "Foreign born"

gen  countrygrp=1 if flandgrp==. /*Sweden*/
replace countrygrp=2 if flandgrp>=26 & flandgrp<=28 /* Nordic countries */
replace countrygrp=3 if (flandgrp>=32 & flandgrp<=34) | flandgrp==38 | flandgrp==39 | flandgrp==52 /* The West */ /* Includes West Europe, North America and Oceania */
replace countrygrp=4 if (flandgrp>=29 & flandgrp<=31) | (flandgrp>=35 & flandgrp<=37) /* East Europe */
replace countrygrp=5 if flandgrp==44 | flandgrp==46 | flandgrp==47 | flandgrp==48 /* North Africa and the Middle East */
replace countrygrp=6 if flandgrp==43 | flandgrp==45                  /* Sub-Saharan Africa */
replace countrygrp=7 if flandgrp>=49 & flandgrp<=51  /* Asia */
replace countrygrp=8 if (flandgrp>=40 & flandgrp<=42) /* Latin America */
replace countrygrp=99 if flandgrp==53                /* Unknown */
lab def fl 1 "Sweden" 2 "Nordic countries" 3 "The West" 4 "East Europe" 5 "North Africa and the Middle East" ///
6 "Sub-Saharan Africa" 7 "Asia and Oceania" 8 "Latin America" 99 "Unknown"
lab val countrygrp fl

sort dnr201966 year
save louise8516, replace

************************************************
*** Add disposable income and capital income ***
************************************************

* 1990
forvalues I=1990(1)1990{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'
merge m:1 year using "P:\2019\66\Use\basbelopp.dta", keep(master match)
drop _merge

gen disppeb=disppeb1*pbb
gen dispfab=dispfab1*pbb
drop disppeb1 dispfab1

cap drop disppeb2
cap drop dispfab2

save disp_kap_`I', replace
}

* 1991-1994
forvalues I=1991(1)1994{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'
merge m:1 year using "P:\2019\66\Use\basbelopp.dta", keep(master match)
drop _merge

gen disppeb=disppeb1*pbb
gen dispfab=dispfab1*pbb
drop disppeb1 dispfab1

cap drop disppeb2
cap drop dispfab2
cap drop dispink

replace kapink=kapink*100
replace pasnar=pasnar*100

save disp_kap_`I', replace
}

* 1995-2000
forvalues I=1995(1)2000{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'
merge m:1 year using "P:\2019\66\Use\basbelopp.dta", keep(master match)
drop _merge

gen disppeb=disppeb1*pbb
gen dispfab=dispfab1*pbb
drop disppeb1 dispfab1
replace dispink=dispink*100

cap drop disppeb2
cap drop dispfab2

replace kapink=kapink*100
replace pasnar=pasnar*100

save disp_kap_`I', replace
}

* 2001-2007
forvalues I=2001(1)2007{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'

gen disppeb=dispeb1m*100
gen dispfab=disfab1m*100
drop dispeb1m disfab1m

replace dispink=dispink*100

replace kapink=kapink*100
replace pasnar=pasnar*100

save disp_kap_`I', replace
}

* 2008
forvalues I=2008(1)2008{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'

gen disppeb=disfab1m_ny*100
gen dispfab=dispeb1m_ny*100
drop dispeb1m_ny disfab1m_ny

drop dispink
rename dispink_ny dispink
replace dispink=dispink*100

cap drop dispeb1m
cap drop disfab1m

replace kapink=kapink*100
replace pasnar=pasnar*100

save disp_kap_`I', replace
}

* 2009-2015
forvalues I=2009(1)2015{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'

gen disppeb=dispeb1m*100
gen dispfab=disfab1m*100
drop dispeb1m disfab1m

replace dispink=dispink*100

replace kapink=kapink*100
replace pasnar=pasnar*100

cap drop dispinkke04

save disp_kap_`I', replace
}

* 2016-2017
forvalues I=2016(1)2017{
use "P:\2019\66\K2\louisesys`I'.dta", clear
gen year=`I'

foreach var in kapink pasnar dispeb1m disfab1m dispink{
destring `var', replace
}

gen disppeb=dispeb1m*100
gen dispfab=disfab1m*100
drop dispeb1m disfab1m

replace dispink=dispink*100
cap drop dispinkke04

replace kapink=kapink*100
replace pasnar=pasnar*100

save disp_kap_`I', replace
}

* Append all data sets *
use disp_kap_1990, clear
forvalues I=1991/2017{
append using disp_kap_`I'
}

cap drop dispinkke04
drop pbb
duplicates drop dnr201966 year, force
sort dnr201966 year
compress
save disp_kap_9017, replace

* Merge on LOUISE data set *
use louise8516, clear
merge 1:1 dnr201966 year using disp_kap_9017, keep(master match)
drop _merge
replace dispink=0 if dispink<0
replace disppeb=0 if disppeb<0
replace dispfab=0 if dispfab<0
foreach var in disppeb dispink dispfab kapink pasnar{
gen `var'real=round(`var'/cpi)
}
label var disppeb "Disposable income individual"
label var dispfab "Disposable income family"
label var dispink "Disposable income individual"
label var dispinkreal "Disposable income individual real"
label var kapink "Capital income"
label var pasnar "Passive self-employment income"
label var disppebreal "Disposable income individual real"
label var dispfabreal "Disposable income family real"
label var kapinkreal "Capital income real"
label var pasnarreal "Passive self-employment income real"
gen totinclkapink=totinc+pasnar+kapink
gen totinclkapinkreal=totincreal+pasnarreal+kapinkreal
label var totinclkapinkreal "Total income including kapink and pasnar real"
label var totinclkapink "Total income including kapink and pasnar"
compress
sort dnr201966 year
save louise8516, replace

*** Add education measure fine level ***

use dnr201966 year hsunall using louisesys1985, clear
forvalues I=1986/2016{
append using louisesys`I', keep(dnr201966 year hsunall)
}
sort dnr201966 year
save hsunall_8516, replace

use louise8516, clear
merge 1:1 dnr201966 year using hsunall_8516, keep(master match)
drop _merge
replace hsunall=. if hsunall==9 | hsunall==8
gen missingeduc=hsunall==.
bys dnr201966: egen maxhedu=max(hsunall)
label var maxhedu "Max education level achieved"
gen missingmaxhedu=maxhedu==.
replace maxhedu=1 if maxhedu==.
compress
sort dnr201966 year
save louise8516, replace

**************************************
*** Add public/private information ***
**************************************

* Anst *

forvalues I=85/99{
use "P:\2019\66\K2\anst`I'.dta", clear
gen year=19`I'
gsort dnr201966 -lonfink
duplicates drop dnr201966, force
keep dnr201966 dnr201966_peorgnr cfarnr year
save anst19`I', replace
}

forvalues I=0/9{
use "P:\2019\66\K2\anst0`I'.dta", clear
gen year=200`I'
gsort dnr201966 -lonfink
duplicates drop dnr201966, force
keep dnr201966 dnr201966_peorgnr cfarnr year
save anst200`I', replace
}

forvalues I=10/18{
use "P:\2019\66\K2\anst`I'.dta", clear
gen year=20`I'
gsort dnr201966 -lonfink
duplicates drop dnr201966, force
keep dnr201966 dnr201966_peorgnr cfarnr year
save anst20`I', replace
}

* Append data sets *
use anst1985, clear
forvalues I=1986/2018{
append using anst`I'
}
compress
sort dnr201966 year
save anst8518, replace

* Ftgast *

forvalues I=85/98{
use "P:\2019\66\K2\ftgast`I'.dta", clear
gen year=19`I'
gen sektor=substr(instkod,1,1)
gen public=sektor=="1"
replace public=. if sektor==""
keep dnr201966_peorgnr cfarnr year public
save ftgast19`I', replace
}

forvalues I=99/99{
use "P:\2019\66\K2\ftgast`I'.dta", clear
gen year=19`I'
gen sektor2=substr(sektor,1,1)
gen public=(sektor2=="3" | sektor2=="4" | sektor2=="5")
replace public=. if sektor2==""
keep dnr201966_peorgnr cfarnr year public
save ftgast19`I', replace
}

forvalues I=0/9{
use "P:\2019\66\K2\ftgast0`I'.dta", clear
gen year=200`I'
gen sektor2=substr(sektor,1,1)
gen public=(sektor2=="3" | sektor2=="4" | sektor2=="5")
replace public=. if sektor2==""
keep dnr201966_peorgnr cfarnr year public
save ftgast200`I', replace
}

forvalues I=10/13{
use "P:\2019\66\K2\ftgast`I'.dta", clear
gen year=20`I'
gen sektor2=substr(sektor,1,1)
gen public=(sektor2=="3" | sektor2=="4" | sektor2=="5")
replace public=. if sektor2==""
keep dnr201966_peorgnr cfarnr year public
save ftgast20`I', replace
}

forvalues I=14/18{
use "P:\2019\66\K2\ftgast`I'.dta", clear
gen year=20`I'
gen sektor2=substr(sektor,1,3)
gen public=(sektor2=="131")
replace public=. if sektor2==""
keep dnr201966_peorgnr cfarnr year public
save ftgast20`I', replace
}

* Append data sets *
use ftgast1985, clear
forvalues I=1986/2018{
append using ftgast`I'
}
compress
sort dnr201966_peorgnr year
save ftgast8518, replace

use ftgast8518, clear
drop cfarnr
drop if dnr201966_peorgnr==""
duplicates drop
sort dnr201966 year
save ftgast8518_peorgnr, replace

* Merge anst and ftgast *
use anst8518, clear
sort dnr201966_peorgnr year
merge m:1 dnr201966_peorgnr year using ftgast8518_peorgnr, ///
keep(master match)
drop _merge
sort dnr201966 year
save public8518, replace

*** Add on to LOUISE ***
use louise8516, clear
merge 1:1 dnr201966 year using public8518, keep(master match) ///
keepusing(public)
drop _merge
save louise8516, replace

************************************************
*** Add information on work-related benefits ***
************************************************

* 1985-1989
forvalues I=1985(1)1989{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
replace arbers=arbers*100
save forvers_`I', replace
}

* 1990-2000
forvalues I=1990(1)2000{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
merge m:1 year using "P:\2019\66\Use\basbelopp.dta", keep(master match)
drop _merge

cap destring socbas, replace
gen socbasm=socbas*pbb
/*
	cap destring forpeng, replace
	cap destring forvab, replace
	gen parben=(forpeng+forvab)*100
	keep year parben 
*/
keep dnr201966 year socbasm
save forvers_`I', replace
}

*2001-2016
forvalues I=2001(1)2016{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
cap destring socbasm, replace
replace socbasm=socbasm*100 
/*
	cap destring forvers, replace
	cap destring forpeng, replace
	cap destring forvab, replace
	replace forvers=forvers*100
	gen parben=(forpeng+forvab)*100
keep dnr201966 year forvers parben
*/
keep dnr201966 year socbasm
save forvers_`I', replace
}

* Append data sets *
use forvers_1985, clear
forvalues I=1986/2016{
append using forvers_`I'
}
foreach var in socbasm arbers{
replace `var'=0 if `var'<0
}
duplicates drop dnr201966 year, force
compress
sort dnr201966 year
save forvers8516, replace

*** Add on to LOUISE ***
use louise8516, clear
merge 1:1 dnr201966 year using forvers8516, keep(master match)
drop _merge
gen forvers=labinc+socbasm
*replace forvers=labinc+arbers if year<=1989
*gen labparinc=labinc+parben
label var forvers "Labor income and work-related benefits"
*label var labparinc "Labor income and parental leave benefits"
label var socbasm "Work-related benefits"
label var arbers "Work-related benefits"
save louise8516, replace

*******************************************************************
*** Add information on unemployment benefits and parental leave ***
*******************************************************************

* 1990-1992
forvalues I=1990(1)1992{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+kas+utbbidr)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 1993-1993
forvalues I=1993(1)1993{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+kas+utbbidr+utbbarb+utbblan+alubidr)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 1994-1994
forvalues I=1994(1)1994{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+kas+kasees+amk+utbbidr+utbbarb+utbblan+aluku+alukas+aluamk)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 1995-1995
forvalues I=1995(1)1995{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+kas+kasees+amk+utbbidr+utbbarb+utbblan+aluku+alukas+aluamk+aluees)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 1996-1996
forvalues I=1996(1)1996{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+kas+kasees+amk+utbbidr+aluku+alukas+aluamk+aluees)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 1997-1998
forvalues I=1997(1)1998{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+kas+kasees+amk+utbbidr+aluku+alukas+aluees+ota)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 1999-2002
forvalues I=1999(1)2002{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+utbbidr+aluku)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 2003-2015
forvalues I=2003(1)2015{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+utbbidr)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* 2016-2016
forvalues I=2016(1)2016{
use "P:\2019\66\K3\louisesys`I'.dta", clear
gen year=`I'
	destring forpeng forvab akassa utbbidr, replace
	gen parben=(forpeng+forvab)*100
	replace forpeng=forpeng*100
	replace forvab=forvab*100
	gen unemp=(akassa+utbbidr)*100
	foreach var in parben forpeng forvab unemp{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 parben forpeng forvab unemp
save louise_uipl`I', replace
}

* Append data sets *
use louise_uipl1990, clear
forvalues I=1991/2016{
append using louise_uipl`I'
}
duplicates drop dnr201966 year, force
compress
sort dnr201966 year
save louise_uipl9016, replace

*** Add on to LOUISE ***
use louise8516, clear
merge 1:1 dnr201966 year using louise_uipl9016, keep(master match)
drop _merge
label var parben "Parental leave benefits"
label var forpeng "Long-term PL ben"
label var forvab "Temporary PL ben"
label var unemp "Unemployment benefits"
save louise8516, replace

***************************************
*** Add information on study grants ***
***************************************

* 1990-1992
forvalues I=1990(1)1992{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+sxsxalan+kortstu+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* 1993-1994
forvalues I=1993(1)1994{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+studpeng+sxsxalan+kortstu+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* 1995-1996
forvalues I=1995(1)1996{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+svuxvuxa+sxsxalan+kortstu+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}


* 1997-2001
forvalues I=1997(1)2001{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+svuxa+svux+svuxalan+svuxlan+sutkun+kortstu+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* 2002-2002
forvalues I=2002(1)2002{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+svuxa+svux+svuxalan+svuxlan+sutkun+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* 2003-2003
forvalues I=2003(1)2003{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+stud+svuxa+svux+svuxalan+svuxlan+sutkun+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* 2004-2015
forvalues I=2004(1)2015{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
	gen studben=(studmed+stud+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* 2016-2016
forvalues I=2016(1)2016{
use "P:\2019\66\K4\louisesys`I'.dta", clear
gen year=`I'
destring studmed stud utbdoc, replace
	gen studben=(studmed+stud+utbdoc)*100
	foreach var in studben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
save louise_stud`I', replace
}

* Append data sets *
use louise_stud1990, clear
forvalues I=1991/2016{
append using louise_stud`I'
}
duplicates drop dnr201966 year, force
compress
sort dnr201966 year
save louise_stud9016, replace

keep if age>=25 & age<=55


*** Add on to LOUISE ***
use louise8516, clear
merge 1:1 dnr201966 year using louise_stud9016, keep(master match)
drop _merge
label var studben "Study benefits"
save louise8516, replace

***********************************************************
*** Add information on sickness and disability benefits ***
***********************************************************

* 1990-1991
forvalues I=1990(1)1991{
use "P:\2019\66\K5\louisesys`I'.dta", clear
gen year=`I'
	gen sickben=(sjukpp)*100
	gen disben=(folkfort+folksjuk+atpfort+atpsjuk)*100
	foreach var in sickben disben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 sickben disben
save louise_sidi`I', replace
}

* 1992-1992
forvalues I=1992(1)1992{
use "P:\2019\66\K5\louisesys`I'.dta", clear
gen year=`I'
	gen sickben=(sjukpp+rehabers+arbskers)*100
	gen disben=(folkfort+folksjuk+atpfort+atpsjuk)*100
	foreach var in sickben disben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 sickben disben
save louise_sidi`I', replace
}

* 1993-2002
forvalues I=1993(1)2002{
use "P:\2019\66\K5\louisesys`I'.dta", clear
gen year=`I'
	gen sickben=(sjukpp+rehabers+arbskers)*100
	gen disben=(folkfort+atpfortsjuk)*100
	foreach var in sickben disben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 sickben disben
save louise_sidi`I', replace
}

* 2003-2015
forvalues I=2003(1)2015{
use "P:\2019\66\K5\louisesys`I'.dta", clear
gen year=`I'
	gen sickben=(sjukpp+rehabers+arbskers)*100
	gen disben=(fortid)*100
	foreach var in sickben disben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 sickben disben
save louise_sidi`I', replace
}

* 2016-2016
forvalues I=2016(1)2016{
use "P:\2019\66\K5\louisesys`I'.dta", clear
gen year=`I'
destring sjukpp rehabers arbskers fortid, replace
	gen sickben=(sjukpp+rehabers+arbskers)*100
	gen disben=(fortid)*100
	foreach var in sickben disben{
	replace `var'=0 if `var'<0
	replace `var'=0 if `var'==.
	}
	keep year dnr201966 sickben disben
save louise_sidi`I', replace
}

* Append data sets *
use louise_sidi1990, clear
forvalues I=1991/2016{
append using louise_sidi`I'
}
duplicates drop dnr201966 year, force
compress
sort dnr201966 year
save louise_sidi9016, replace

*** Add on to LOUISE ***
use louise8516, clear
merge 1:1 dnr201966 year using louise_sidi9016, keep(master match)
drop _merge
label var sickben "Sickness benefits"
label var disben "Disability benefits"
gen sumben=sickben+disben+studben+parben+unemp
gen benefits=forvers-labinc
save louise8516, replace

************************
*** Add hours worked ***
************************

*** Arb ***
* 1985-1994 *
forvalues I=85/94{
use "P:\2019\66\K3\arb`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr manl redovar anstform arbtim ///
lonarbtid tidprestlon
destring manl redovar anstform arbtim ///
lonarbtid tidprestlon, replace
save arb19`I', replace
}

* 1995-1998 *
forvalues I=95/98{
use "P:\2019\66\K3\arb`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr manl redovar arbtim ///
lonarbtid tidprestlon
destring manl redovar arbtim ///
lonarbtid tidprestlon, replace
save arb19`I', replace
}

* 1999 *
forvalues I=99/99{
use "P:\2019\66\K3\arb`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar arbtim ///
lonarbtid tidprestlon
destring tjomf manl redovar arbtim ///
lonarbtid tidprestlon, replace
save arb19`I', replace
}

* 2000-2009 *
forvalues I=0/9{
use "P:\2019\66\K3\arb0`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar arbtim ///
lonarbtid tidprestlon anstform
destring tjomf manl redovar anstform arbtim ///
lonarbtid tidprestlon anstform, replace
save arb200`I', replace
}

* 2010-2016 *
forvalues I=10/16{
use "P:\2019\66\K3\arb`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar arbtim ///
lonarbtid tidprestlon anstform
destring tjomf manl redovar anstform arbtim ///
lonarbtid tidprestlon anstform, replace
save arb20`I', replace
}

* Combine years *
use arb1985, clear
forvalues I=1986/2016{
append using arb`I'
}
gen sector="arb"
compress
rename redovar year
replace year=2000+year if year<=16

* Arbtim *
replace arbtim=0 if arbtim<0
replace arbtim=round(arbtim/3) if year<=1996
replace arbtim=round(arbtim/2) if year>=1997 & year<=2000
order dnr201966 year
sort dnr201966 year
save arb8516, replace

*** Tjm ***
* 1985-1990 *
forvalues I=85/90{
use "P:\2019\66\K3\tjm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh
destring manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh, replace
save tjm19`I', replace
}

* 1991 *
forvalues I=91/91{
use "P:\2019\66\K3\tjm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr manl redovar anstform ///
lonarbtid ovktid
destring manl redovar anstform ///
lonarbtid ovktid, replace
save tjm19`I', replace
}

* 1992-1994 *
forvalues I=92/94{
use "P:\2019\66\K3\tjm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh
destring manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh, replace
save tjm19`I', replace
}

* 1995 *
forvalues I=95/95{
use "P:\2019\66\K3\tjm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh
destring tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh, replace
replace anstform=2 if anstform==1
replace anstform=1 if anstform==0
save tjm19`I', replace
}

* 1996-1999 *
forvalues I=96/99{
use "P:\2019\66\K3\tjm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh arbtim ovttim
destring tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh arbtim ovttim, replace
save tjm19`I', replace
}

* 2000-2009 *
forvalues I=0/9{
use "P:\2019\66\K3\tjm0`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh arbtim ovttim
destring tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh arbtim ovttim, replace
save tjm200`I', replace
}

* 2010-2016 *
forvalues I=10/16{
use "P:\2019\66\K3\tjm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh arbtim ovttim
destring tjomf manl redovar anstform ///
lonarbtid tidprestlon ovktid ovktidh arbtim ovttim, replace
save tjm20`I', replace
}

* Combine years *
use tjm1985, clear
forvalues I=1986/2016{
append using tjm`I'
}
gen sector="tjm"
rename redovar year
replace year=2000+year if year<=16

* Arbtim *
replace arbtim=0 if arbtim<0
replace arbtim=round(arbtim/2) if year>=1997 & year<=2000

compress
order dnr201966 year
sort dnr201966 year
save tjm8516, replace

*** Kommun ***
* 1985-1989 *
forvalues I=85/89{
use "P:\2019\66\K3\kommun`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar
destring tjomf manl grlon rortup redovar, replace
save kommun19`I', replace
}

* 1990-1994 *
forvalues I=90/94{
use "P:\2019\66\K3\kommun`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup ///
redovar arbtim
destring tjomf manl grlon rortup redovar arbtim, replace
save kommun19`I', replace
}

* 1995-1999 *
forvalues I=95/99{
use "P:\2019\66\K3\kommun`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup ///
redovar arbtim
destring tjomf manl grlon rortup redovar arbtim, replace
save kommun19`I', replace
}

* 2000-2009 *
forvalues I=0/9{
use "P:\2019\66\K3\kommun0`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup ///
redovar arbtim
destring tjomf manl grlon rortup redovar arbtim, replace
save kommun200`I', replace
}

* 2010-2016 *
forvalues I=10/16{
use "P:\2019\66\K3\kommun`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup ///
redovar arbtim
destring tjomf manl grlon rortup redovar arbtim, replace
save kommun20`I', replace
}

* Combine years *
use kommun1985, clear
forvalues I=1986/2016{
append using kommun`I'
}
gen sector="kommun"
compress
rename redovar year
replace year=2000+year if year<=16
order dnr201966 year
sort dnr201966 year
save kommun8516, replace

*** Landskomm ***
* 1990-1994 *
forvalues I=90/94{
use "P:\2019\66\K3\landskomm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon ///
rortup redovar overttillagg arbtim
destring tjomf manl grlon ///
rortup redovar overttillagg arbtim, replace
save landskomm19`I', replace
}

* 1995-1998 *
forvalues I=95/98{
use "P:\2019\66\K3\landskomm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon ///
rortup redovar overttillagg arbtim
destring tjomf manl grlon ///
rortup redovar overttillagg arbtim, replace
save landskomm19`I', replace
}

* 1999 *
forvalues I=99/99{
use "P:\2019\66\K3\landskomm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon ///
rortup redovar overttillagg arbtim
destring tjomf manl grlon ///
rortup redovar overttillagg arbtim, replace
save landskomm19`I', replace
}

* 2000-2009 *
forvalues I=0/9{
use "P:\2019\66\K3\landskomm0`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon ///
rortup redovar overttillagg arbtim
destring tjomf manl grlon ///
rortup redovar overttillagg arbtim, replace
save landskomm200`I', replace
}

* 2010-2016 *
forvalues I=10/16{
use "P:\2019\66\K3\landskomm`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon ///
rortup redovar overttillagg arbtim
destring tjomf manl grlon ///
rortup redovar overttillagg arbtim, replace
save landskomm20`I', replace
}

* Combine years *
use landskomm1990, clear
forvalues I=1991/2016{
append using landskomm`I'
}
gen sector="landskomm"
compress
rename redovar year
replace year=2000+year if year<=16
order dnr201966 year
sort dnr201966 year
save landskomm9016, replace

*** Stat ***
* 1985-1989 *
forvalues I=85/89{
use "P:\2019\66\K3\stat`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar
destring tjomf manl grlon rortup redovar, replace
save stat19`I', replace
}

* 1990-1994 *
forvalues I=90/94{
use "P:\2019\66\K3\stat`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar ///
overttillagg
destring tjomf manl grlon rortup redovar overttillagg, replace
save stat19`I', replace
}

* 1995-1996 *
forvalues I=95/96{
use "P:\2019\66\K3\stat`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar
destring tjomf manl grlon rortup redovar, replace
save stat19`I', replace
}

* 1997-1999 *
forvalues I=97/99{
use "P:\2019\66\K3\stat`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar ///
overttillagg
destring tjomf manl grlon rortup redovar overttillagg, replace
save stat19`I', replace
}

* 2000-2009 *
forvalues I=0/9{
use "P:\2019\66\K3\stat0`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar ///
overttillagg
destring tjomf manl grlon rortup redovar overttillagg, replace
save stat200`I', replace
}

* 2010-2016 *
forvalues I=10/16{
use "P:\2019\66\K3\stat`I'", clear
keep dnr201966 dnr201966_peorgnr cfarnr tjomf manl grlon rortup redovar ///
overttillagg
destring tjomf manl grlon rortup redovar overttillagg, replace
save stat20`I', replace
}

* Combine years *
use stat1985, clear
forvalues I=1986/2016{
append using stat`I'
}
gen sector="stat"
compress
rename redovar year
replace year=2000+year if year<=16
order dnr201966 year
sort dnr201966 year
save stat8516, replace

* Combine data sets *
use arb8516, clear
foreach var in tjm kommun stat{
append using `var'8516
}
append using landskomm9016
order dnr201966 dnr201966_peorgnr year cfarnr sector tjomf arbtim anstform ///
ovktid ovktidh ovttim manl lonarbtid tidprestlon grlon rortup ///
overttillagg

* Arbtim
replace arbtim=0 if arbtim<0
replace arbtim=300 if arbtim>300 & arbtim!=.

* Tjomf 
replace tjomf=100 if tjomf>100 & tjomf<.

* Part time variables *
gen shortpt_tjomf=tjomf>=1/40 & tjomf<50
replace shortpt_tjomf=. if tjomf==.
gen longpt_tjomf=tjomf>=50 & tjomf<87.5
replace longpt_tjomf=. if tjomf==.
gen partt_tjomf=tjomf<87.5
replace partt_tjomf=. if tjomf==.
gen fullt_tjomf=tjomf>=87.5 & tjomf!=.
replace fullt_tjomf=. if tjomf==.

* Part time anstform *
gen fullt_anstform=(anstform==1)
replace fullt_anstform=. if anstform==.
replace fullt_anstform=. if anstform==0
gen partt_anstform=(anstform==2)
replace partt_anstform=. if anstform==.
replace partt_anstform=. if anstform==0

* Drop duplicates *
gsort dnr201966 year -tjomf -arbtim -manl
duplicates drop dnr201966 year, force
sort dnr201966 year
save lonstr8516, replace

