cd "P:\2019\66\Use\"

***********************************
*** 1. Sample selection logearn ***
***********************************

*** Create data set researn1F data ***
use "P:\2019\66\dta\researn1F.dta"
reshape long researn1F arcearn1F, i(personid) j(year)
rename personid persid
sort persid year
save sample_researn1F, replace

*** Create data set ***
use "P:\2019\66\dta\researn.dta"
drop yob male
reshape long logearnc logearn researnc researn labor, i(personid) j(year)
rename personid persid
merge 1:1 persid year using "P:\2019\66\dta\data_long.dta"
drop if _merge==1
drop _merge

foreach var in logearn logearnc{
gen insample_`var'=(`var'!=.)
}
foreach var in logearn logearnc{
gen dropped_`var'=1-insample_`var'
}
foreach var in logearn logearnc{
gen dropped_`var'_pos=dropped_`var'
replace dropped_`var'_pos=. if totincreal==0
}
foreach var in logearn logearnc{
gen dropped_`var'_zero=dropped_`var'
replace dropped_`var'_zero=0 if totincreal>0 & totincreal!=.
}

merge 1:1 persid year using "P:\2019\66\Use\louise8516", keep(master match) ///
keepusing(foreignb hsunall maxhedu missingeduc missingmaxhedu ///
public disppeb dispfab dispink dispinkreal ///
kapink pasnar disppebreal dispfabreal kapinkreal pasnarreal totinclkapink ///
totinclkapinkreal forvers socbasm countrygrp)
drop _merge

keep if age>=25 & age<=55

* Re-group country groups *
gen cgroup2=1 if countrygrp==2
replace cgroup2=2 if countrygrp==4
replace cgroup2=3 if countrygrp==5 | countrygrp==6
replace cgroup2=4 if countrygrp==7
replace cgroup2=5 if countrygrp==3 | countrygrp==8 | countrygrp==99

lab def fl2 1 "Nordic" 2 "East Europe" 3 "Middle East & Africa" 4 "Asia" 5 "Other"
lab val cgroup2 fl2

sort persid year
merge 1:1 persid year using sample_researn1F, keep(master match)
drop _merge

foreach var in researn1F arcearn1F{
gen insample_`var'=(`var'!=.)
gen dropped_`var'=1-insample_`var'
}

foreach var in researn1F arcearn1F{
gen insample_`var'_emp=(`var'!=.)
gen dropped_`var'_emp=1-insample_`var'_emp
replace insample_`var'_emp=. if insample_logearn==0
replace dropped_`var'_emp=. if insample_logearn==0
replace insample_`var'_emp=. if age>=54
replace dropped_`var'_emp=. if age>=54
}

bys persid: gen indata_1F=F.year!=.
replace indata_1F=. if age>=54

foreach var in researn1F arcearn1F{
replace insample_`var'_emp=. if indata_1F==0
replace dropped_`var'_emp=. if indata_1F==0
}

save "P:\2019\66\dta\sampleselection.dta", replace

*** Compare samples ***

use "P:\2019\66\dta\sampleselection.dta", clear

drop if age==55

* Dropped *

preserve
collapse dropped_logearn dropped_logearnc dropped_logearn_pos ///
dropped_logearnc_pos dropped_logearn_zero dropped_logearnc_zero, by(year male)
save droppedbyyear_gender, replace
restore

preserve
gen agegroup=1 if age>=25 & age<=34
replace agegroup=2 if age>34 & age<=44
replace agegroup=3 if age>44 & age<=54
collapse dropped_logearn dropped_logearnc dropped_logearn_pos ///
dropped_logearnc_pos dropped_logearn_zero dropped_logearnc_zero, ///
by(year agegroup male)
save droppedbyyear_gender_age, replace
restore

preserve
collapse dropped_logearn dropped_logearnc dropped_logearn_pos ///
dropped_logearnc_pos dropped_logearn_zero dropped_logearnc_zero, ///
by(year male foreignb)
save droppedbyyear_gender_imm, replace
restore

preserve
collapse dropped_logearn dropped_logearnc dropped_logearn_pos ///
dropped_logearnc_pos dropped_logearn_zero dropped_logearnc_zero, by(year male cgroup2)
save droppedbyyear_gender_cgroup2, replace
restore

* In sample *

preserve
collapse insample*, ///
by(year foreignb)
save insample_imm, replace
restore

preserve
collapse insample*, by(year cgroup2)
save insample_cgroup2, replace
restore

*** Fig: Employment by gender ***

use droppedbyyear_gender, clear

gen emp=1-dropped_logearn
gen empzero=1-dropped_logearn_zero
drop dropped*

reshape wide emp*, i(year) j(male)

label var emp0 "Women"
label var emp1 "Men"
label var year Year

twoway 	///
	(line emp0 emp1 year), ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Employment rate") yscale(range(0.5 1)) ylabel(0.5(0.1)1) ///
	 legend(cols(1)) ///
	saving("P:\2019\66\Output\lfp_gender", replace)
	graph export "P:\2019\66\Output\lfp_gender.pdf", replace

*** Fig: Employment by immigration and gender in one figure ***

use droppedbyyear_gender_imm, clear

gen emp=1-dropped_logearn
drop dropped*

reshape wide emp, i(year male) j(foreignb)
reshape wide emp*, i(year) j(male)

label var emp01 "Native men"
label var emp11 "Foreign-born men"
label var emp00 "Native women"
label var emp10 "Foreign-born women"
label var year Year

twoway 	///
	(line emp* year),	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Employment rate") yscale(range(0.5 1)) ylabel(0.5(0.1)1) ///
	saving("P:\2019\66\Output\lfp_imm_gender", replace)
	graph export "P:\2019\66\Output\lfp_imm_gender.pdf", replace

*** Fig: Employment by gender and age ***

use droppedbyyear_gender_age, clear

gen emp=1-dropped_logearn
drop dropped*

reshape wide emp, i(year male) j(agegroup)

label var emp1 "25-34"
label var emp2 "35-44"
label var emp3 "45-55"
label var year Year
	
twoway 	///
	(line emp* year) if male==0,	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Employment rate") yscale(range(0.7 1)) ylabel(0.7(0.1)1) legend(cols(3)) ///
	saving("P:\2019\66\Output\lfp_age_women", replace)
	graph export "P:\2019\66\Output\lfp_age_women.pdf", replace

twoway 	///
	(line emp* year) if male==1,	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Employment rate") yscale(range(0.7 1)) ylabel(0.7(0.1)1) legend(cols(3)) ///
	saving("P:\2019\66\Output\lfp_age_men", replace)
	graph export "P:\2019\66\Output\lfp_age_men.pdf", replace

*** Fig: Employment by gender and country group ***
	
use droppedbyyear_gender_cgroup2, clear
gen emp=1-dropped_logearn
drop dropped*
drop if cgroup2==.
reshape wide emp, i(year male) j(cgroup2)

label var emp1 "Nordic"
label var emp2 "East Europe"
label var emp3 "Africa & M. East"
label var emp4 "Asia"
label var emp5 "Other"
label var year Year

twoway 	///
	(line emp1 emp2 emp5 emp4 emp3 year) if male==0,	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Employment rate") legend(cols(3)) ///
	yscale(range(0.3 0.9)) ylabel(0.3(0.1)0.9) ///
	saving("P:\2019\66\Output\lfp_cgroup2_women", replace)
	graph export "P:\2019\66\Output\lfp_cgroup2_women.pdf", replace

twoway 	///
	(line emp1 emp2 emp5 emp4 emp3 year) if male==1,	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Employment rate") legend(cols(3)) ///
	yscale(range(0.3 0.9)) ylabel(0.3(0.1)0.9) ///
	saving("P:\2019\66\Output\lfp_cgroup2_men", replace)
	graph export "P:\2019\66\Output\lfp_cgroup2_men.pdf", replace

*** Fig: In sample consecutive years (researn 1F) by immigrant status ***

use insample_imm, clear
reshape wide insample_logearn insample_logearnc insample_researn1F insample_arcearn1F ///
insample_researn1F_emp insample_arcearn1F_emp, i(year) j(foreignb)
drop if year==2016
label var insample_researn1F_emp0 "Natives"
label var insample_researn1F_emp1 "Foreign-born"
label var year Year

twoway 	///
	(line insample_researn1F_emp* year),	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share employees in year t employed in t+1") legend(cols(3)) ///
	yscale(range(0.8 1)) ylabel(0.8(0.05)1) ///
	saving("P:\2019\66\Output\ins_researn1f_imm", replace)
	graph export "P:\2019\66\Output\ins_researn1f_imm.pdf", replace

*** Fig: In sample consecutive years (researn 1F) by country group ***
	
use insample_cgroup2, clear
drop if cgroup2==.
reshape wide insample_logearn insample_logearnc insample_researn1F insample_arcearn1F ///
insample_researn1F_emp insample_arcearn1F_emp, i(year) j(cgroup2)

drop if year==2016

label var insample_researn1F_emp1 "Nordic"
label var insample_researn1F_emp2 "East Europe"
label var insample_researn1F_emp3 "Africa & M. East"
label var insample_researn1F_emp4 "Asia"
label var insample_researn1F_emp5 "Other"
label var year Year
 
twoway 	///
	(line insample_researn1F_emp1 insample_researn1F_emp2 insample_researn1F_emp5 insample_researn1F_emp4 insample_researn1F_emp3 year),	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share employees in year t employed in t+1") legend(cols(3)) ///
	yscale(range(0.8 1)) ylabel(0.8(0.05)1) ///
	saving("P:\2019\66\Output\ins_researn1f_cgroup2", replace)
	graph export "P:\2019\66\Output\ins_researn1f_cgroup2.pdf", replace

*** Table: Sumstat ***

use "P:\2019\66\dta\sampleselection.dta", clear

keep if insample_logearn==1
gen higheduc=educ==2
cap drop _merge

merge 1:1 dnr201966 year using "P:\2019\66\Use\lonstr8516", ///
keep(master match)
drop _merge

merge 1:1 persid year using "P:\2019\66\Use\louise8516", keep(master match) ///
keepusing(parben unemp forvers sickben disben studben)
drop _merge

keep if year==1985 | year==1995 | year==2005 | year==2015
gen exrate=8.6032 if year==1985
replace exrate=7.1406 if year==1995
replace exrate=7.471 if year==2005
replace exrate=8.435 if year==2015

* forvers socbasm *
gen benefits=forvers-labinc
gen remben=benefits-unemp-parben-sickben-disben

foreach var in forvers socbasm manl unemp parben sickben disben remben{
gen `var'real=round(`var'/cpi)
}

foreach var in totinc labinc selfinc ///
totinclkapink dispink forvers socbasm manl ///
unemp parben sickben disben remben{
gen `var'realusd=`var'real/exrate
}

gen shareben=benefits/forvers
replace shareben=0 if shareben==.
replace shareben=0 if shareben<0
gen indbenefits=shareben>0

gen sdibenrealusd=sickbenrealusd+disbenrealusd

gen parttime=partt_anstform
replace parttime=partt_tjomf if parttime==.

gen parttime_women=parttime if male==0
gen parttime_men=parttime if male==1

log using "P:\2019\66\Output\sumstat.txt", text replace

bys year: sum age male foreignb ///
totincrealusd labincrealusd selfincrealusd ///
forversrealusd shareben dispinkrealusd manlrealusd ///
parttime_women parttime_men

bys year: sum totincrealusd, detail

log close

*** Fig: Polarization of education by origin, 3 education groups ***

use "P:\2019\66\dta\sampleselection.dta", clear
	
keep if insample_logearn==1

gen fb_maxhedu=maxhedu if foreignb==1
tab fb_maxhedu, gen(fb_hedud)

gen nat_maxhedu=maxhedu if foreignb==0
tab nat_maxhedu, gen(nat_hedud)

collapse fb_hedud* nat_hedud*, by(year)
save educfine, replace
	
use educfine, clear

gen group_fb1=fb_hedud1+fb_hedud2
gen group_fb2=fb_hedud3+fb_hedud4
gen group_fb3=fb_hedud5+fb_hedud6+fb_hedud7

label var group_fb1 "Less than high school"
label var group_fb2 "High school"
label var group_fb3 "College"

gen group_nat1=nat_hedud1+nat_hedud2
gen group_nat2=nat_hedud3+nat_hedud4
gen group_nat3=nat_hedud5+nat_hedud6+nat_hedud7

label var group_nat1 "Less than high school"
label var group_nat2 "High school"
label var group_nat3 "College"

label var year Year

twoway (line group_fb* year), ///
	legend(cols(2)) ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) ///
	ytitle("Share") scale(1.2) ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) ///
	saving("P:\2019\66\Output\share_educ3g_imm", replace)
	graph export "P:\2019\66\Output\share_educ3g_imm.pdf", replace

twoway (line group_nat* year), ///
	legend(cols(2)) ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) ///
	ytitle("Share") scale(1.2) ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) ///
	saving("P:\2019\66\Output\share_educ3g_nat", replace)
	graph export "P:\2019\66\Output\share_educ3g_nat.pdf", replace

*** Fig: Share foreign by gender ***

use "P:\2019\66\dta\sampleselection.dta", clear

gen foreignb_ins=foreignb
replace foreignb_ins=. if insample_logearn==0

collapse foreignb foreignb_ins, by(year male)

reshape wide foreignb foreignb_ins, i(year) j(male)

label var foreignb0 "Women, population"
label var foreignb_ins0 "Women, employed"
label var foreignb1 "Men, population"
label var foreignb_ins1 "Men, employed"
label var year "Year"

save shareforeign_gender, replace

use shareforeign_gender, clear
order foreignb*

twoway (line foreignb*  year), ///
	legend(cols(2)) ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share foreign-born")	///
	saving("P:\2019\66\Output\share_foreign_gender", replace)
	graph export "P:\2019\66\Output\share_foreign_gender.pdf", replace

*** Fig: Share foreign-born by birth region ***

use "P:\2019\66\dta\sampleselection.dta", clear

forvalues I=1/5{
    gen indgrp`I'=cgroup2==`I'
	gen indgrp`I'_ins=indgrp`I'
	replace indgrp`I'_ins=. if insample_logearn==0
	}

collapse indgrp*, by(year male)
order year male *_ins

label var indgrp1 "Nordic"
label var indgrp2 "East Europe"
label var indgrp3 "Africa & M. East"
label var indgrp4 "Asia"
label var indgrp5 "Other"

label var indgrp1_ins "Nordic"
label var indgrp2_ins "East Europe"
label var indgrp3_ins "Africa & M. East"
label var indgrp4_ins "Asia"
label var indgrp5_ins "Other"

label var year Year

save share_cgroup2, replace

use share_cgroup2, clear

twoway 	///
	(line indgrp1_ins indgrp2_ins indgrp5_ins indgrp4_ins indgrp3_ins  year) if male==0,	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share foreign-born") legend(cols(3)) ///
	yscale(range(0 0.08)) ylabel(0(0.02)0.08) ///
	saving("P:\2019\66\Output\share_cgroup2_women_emp", replace)
	graph export "P:\2019\66\Output\share_cgroup2_women_emp.pdf", replace

twoway 	///
	(line indgrp1_ins indgrp2_ins indgrp5_ins indgrp4_ins indgrp3_ins year) if male==1,	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share foreign-born") legend(cols(3)) ///
	yscale(range(0 0.08)) ylabel(0(0.02)0.08) ///
	saving("P:\2019\66\Output\share_cgroup2_men_emp", replace)
	graph export "P:\2019\66\Output\share_cgroup2_men_emp.pdf", replace

*** Fig: Share foreign-born by birth region over time pooled ***

use "P:\2019\66\dta\sampleselection.dta", clear

forvalues I=1/5{
    gen indgrp`I'=cgroup2==`I'
	gen indgrp`I'_ins=indgrp`I'
	replace indgrp`I'_ins=. if insample_logearn==0
	}

collapse indgrp*, by(year)
order year *_ins

label var indgrp1 "Nordic"
label var indgrp2 "East Europe"
label var indgrp3 "Africa & M. East"
label var indgrp4 "Asia"
label var indgrp5 "Other"

label var indgrp1_ins "Nordic"
label var indgrp2_ins "East Europe"
label var indgrp3_ins "Africa & M. East"
label var indgrp4_ins "Asia"
label var indgrp5_ins "Other"

label var year Year

save share_cgroup2_pooled, replace

use share_cgroup2_pooled, clear

twoway 	///
	(line indgrp1_ins indgrp2_ins indgrp5_ins indgrp4_ins indgrp3_ins  year),	///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share foreign-born among employed") legend(cols(3)) ///
	yscale(range(0 0.08)) ylabel(0(0.02)0.08) ///
	saving("P:\2019\66\Output\share_cgroup2_emp", replace)
	graph export "P:\2019\66\Output\share_cgroup2_emp.pdf", replace

*** Fig: Share public sector employment ***

use "P:\2019\66\dta\sampleselection.dta", clear
keep if insample_logearn==1

collapse public, by(year male)
save sharepublic, replace

use sharepublic, clear
reshape wide public, i(year) j(male)
label var public0 Women
label var public1 Men
label var year Year

twoway (line public* year), ///
	legend(cols(2) order(1 2)) ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share public sector")	///
	saving("P:\2019\66\Output\share_public_gender", replace)
	graph export "P:\2019\66\Output\share_public_gender.pdf", replace

* By gender and immigrant status *

use "P:\2019\66\dta\sampleselection.dta", clear
keep if insample_logearn==1

collapse public, by(year male foreignb)
save sharepublicimm, replace

use sharepublicimm, clear
reshape wide public, i(year male) j(foreignb)
reshape wide public*, i(year) j(male)
label var public00 "Women, natives"
label var public10 "Women, immigrants"
label var public01 "Men, natives"
label var public11 "Men, immigrants"
label var year Year

twoway (line public* year), ///
	legend(cols(2)) ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.4)	///
	ytitle("Share public sector")	///
	saving("P:\2019\66\Output\share_public_gender_imm", replace)
	graph export "P:\2019\66\Output\share_public_gender_imm.pdf", replace

*** Hours and wages ***

use "P:\2019\66\dta\sampleselection.dta", clear

keep if insample_logearn==1

merge 1:1 dnr201966 year using "P:\2019\66\Use\lonstr8516", ///
keep(master match)
drop _merge

save hoursdata, replace

use hoursdata, clear

gen sector_broad="pub" if sector=="kommun" | sector=="landskomm" | sector=="stat"
replace sector_broad="arb" if sector=="arb"
replace sector_broad="tjm" if sector=="tjm"

keep if year>=1990
drop if sector_broad==""

collapse tjomf ovktid manl ///
shortpt_tjomf longpt_tjomf partt_tjomf fullt_tjomf ///
fullt_anstform partt_anstform, by(male sector_broad year)
save "P:\2019\66\dta\hoursmalesectorbroad", replace

use hoursdata, clear

sort year male totinc
bys year male (totinc): gen n=ceil((_n/_N)*100)

preserve
keep if n==10  | n==50  | n==90
collapse manl, by(year male n)
save wage_perc, replace
restore

* Figures *

use "P:\2019\66\dta\hoursmalesectorbroad", clear
drop if year<1990

reshape wide tjomf ovktid manl ///
shortpt_tjomf longpt_tjomf partt_tjomf fullt_tjomf ///
fullt_anstform partt_anstform, i(year male) j(sector_broad) string

merge m:1 year using "P:\2019\66\dta\cpi", keep(master match)
drop _merge

foreach var in arb tjm pub{
gen manlreal`var'=manl`var'/cpi
}

foreach var in tjomf ovktid manl ///
shortpt_tjomf longpt_tjomf partt_tjomf fullt_tjomf ///
fullt_anstform partt_anstform manlreal{
label var `var'tjm "Private white-collar"
label var `var'arb "Private blue-collar"
label var `var'pub "Public sector"
}
order *arb *tjm *pub
label var year Year

** Fig: Combine partt tjomf & anstform ***

twoway line partt_anstformarb partt_anstformtjm partt_tjomfpub year if male==0, ///
cmissing(n) scheme(s2mono) legend(cols(2)) scale(1.2) ///
graphregion(color(white)) ytitle("Share part-time") ///
yscale(range(0 0.8)) ylabel(0(0.2)0.8) ///
xscale(range(1990 2016)) xlabel(1990(5)2015) ///
saving("P:\2019\66\Output\partt_women", replace)
graph export "P:\2019\66\Output\partt_women.pdf", replace

twoway line partt_anstformarb partt_anstformtjm partt_tjomfpub year if male==1, ///
cmissing(n) scheme(s2mono) legend(cols(2)) scale(1.2) ///
graphregion(color(white)) ytitle("Share part-time") ///
yscale(range(0 0.8)) ylabel(0(0.2)0.8) ///
xscale(range(1990 2016)) xlabel(1990(5)2015) ///
saving("P:\2019\66\Output\partt_men", replace)
graph export "P:\2019\66\Output\partt_men.pdf", replace

* Wage by percentile *

use wage_perc, clear
merge m:1 year using "P:\2019\66\dta\cpi", keep(master match)
drop _merge
gen manlreal=manl/cpi
drop cpi

reshape wide manl manlreal, i(year male) j(n)
label var manl10 "P10"
label var manl50 "P50"
label var manl90 "P90"
label var manlreal10 "P10"
label var manlreal50 "P50"
label var manlreal90 "P90"
label var year Year

twoway (line manlreal* year) if male==0, ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Real wage")	///
	ylabel(20000(10000)50000) yscale(range(20000 50000)) legend(cols(3)) ///
	saving("P:\2019\66\Output\wage_perc_women", replace)
	graph export "P:\2019\66\Output\wage_perc_women.pdf", replace

twoway (line manlreal* year) if male==1, ///
	xlabel(1985(5)2015) scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Real wage")	///
	ylabel(20000(10000)50000) yscale(range(20000 50000)) legend(cols(3)) ///
	saving("P:\2019\66\Output\wage_perc_men", replace)
	graph export "P:\2019\66\Output\wage_perc_men.pdf", replace

*** Benefits ***

*** Create data set ***
use "P:\2019\66\dta\permearn.dta", clear
reshape long permearn, i(personid) j(year)
rename personid persid
sort persid year
save "P:\2019\66\Use\permearn_long.dta", replace

use "P:\2019\66\dta\researn1F.dta", clear
reshape long researn1F arcearn1F, i(personid) j(year)
rename personid persid
sort persid year
save "P:\2019\66\Use\researn1F_long.dta", replace

*** Merge data sets ***
use "P:\2019\66\dta\sampleselection.dta", clear

merge 1:1 persid year using "P:\2019\66\Use\louise8516", keep(master match) ///
keepusing(parben unemp forvers sickben disben studben)
drop _merge

merge 1:1 persid year using "P:\2019\66\Use\permearn_long", keep(master match)
drop _merge

merge 1:1 persid year using "P:\2019\66\Use\researn1F_long", keep(master match)
drop _merge

merge m:1 year using "P:\2019\66\dta\cpi", keep(master match)
drop _merge

keep if year>=1990
keep if insample_logearn==1

gen benefits=forvers-labinc
gen shareben=benefits/(forvers+(totinc-labinc))
replace shareben=0 if shareben<0
gen indbenefits=shareben>0

gen shareui=unemp/(forvers+(totinc-labinc))
replace shareui=0 if shareui<0
gen indunemp=shareui>0

gen sharepl=parben/(forvers+(totinc-labinc))
replace sharepl=0 if sharepl<0
gen indparben=sharepl>0

gen sharesi=sickben/(forvers+(totinc-labinc))
replace sharesi=0 if sharesi<0
gen indsickben=sharesi>0

gen sharedi=disben/(forvers+(totinc-labinc))
replace sharedi=0 if sharedi<0
gen inddisben=sharedi>0

gen sharesdi=(sickben+disben)/(forvers+(totinc-labinc))
replace sharesdi=0 if sharesdi<0
gen indsdiben=sharesdi>0

gen remben=benefits-unemp-parben-sickben-disben
gen shareremben=remben/(forvers+(totinc-labinc))
replace shareremben=0 if shareremben<0
gen indremben=shareremben>0

gen sdiben=sickben+disben

foreach var in forvers benefits unemp parben sickben disben sdiben remben{
gen `var'real=`var'/cpi
}

* Create changes *

sort persid year
gen d_ben=F.benefitsreal-benefitsreal
gen d_shareben=F.shareben-shareben
gen d_entryben=(F.indbenefits==1 & indbenefits==0)
gen d_exitben=(F.indbenefits==0 & indbenefits==1)

foreach var in unemp parben sickben disben sdiben remben{
gen d_`var'=F.`var'real-`var'real
gen d_entry`var'=(F.`var'>0 & `var'==0)
gen d_exit`var'=(F.`var'==0 & `var'>0)
}

foreach var in ui pl si di sdi remben{
gen d_share`var'=F.share`var'-share`var'
}

gen d_ben_tot=(F.benefitsreal-benefitsreal)/(F.totincreal-totincreal)

* Create percentiles *

sort year male totinc
bys year male (totinc): gen n=ceil((_n/_N)*100)

sort year male totinc educ
bys year male educ (totinc): gen n_educ=ceil((_n/_N)*100)

sort year male totinc foreignb
bys year male foreignb (totinc): gen n_imm=ceil((_n/_N)*100)

gen nonwest=1 if foreignb==1 & (cgroup2==1 | cgroup2==2 | cgroup2==5)
replace nonwest=0 if foreignb==1 & (cgroup2==3 | cgroup2==4)
sort year male totinc nonwest
bys year male nonwest (totinc): gen n_nonwest=ceil((_n/_N)*100)
replace n_nonwest=. if foreignb==0

* Create percentiles permearn *
gen ind_permearn=permearn!=.
bys year male ind_permearn (permearn): gen n_permearn=((_n/_N)*100)
replace n_permearn=. if ind_permearn==0

* Create percentiles researn1F *

gen ind_researn1F=researn1F!=.
sort year male researn1F
bys year male ind_researn1F (researn1F): gen n_res=ceil((_n/_N)*100)
replace n_res=. if ind_researn1F==0

sort year male researn1F educ
bys year male educ ind_researn1F (researn1F): gen n_res_educ=ceil((_n/_N)*100)
replace n_res_educ=. if ind_researn1F==0

sort year male researn1F foreignb
bys year male foreignb ind_researn1F (researn1F): gen n_res_imm=ceil((_n/_N)*100)
replace n_res_imm=. if ind_researn1F==0

sort persid year
save "P:\2019\66\Use\desc_benefits.dta", replace

* Collapse per earnings distribution *

use "P:\2019\66\Use\desc_benefits.dta", clear

preserve
keep if n==10  | n==50  | n==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n)
save desc_ben_overall, replace
restore

preserve
keep if n_educ==10  | n_educ==50  | n_educ==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n_educ educ)
save desc_ben_educ, replace
restore

preserve
keep if n_imm==10  | n_imm==25  | n_imm==50  | n_imm==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n_imm foreignb)
save desc_ben_imm, replace
restore

preserve
keep if foreignb==1
keep if n_nonwest==10  | n_nonwest==50  | n_nonwest==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n_nonwest nonwest)
save desc_ben_nonwest, replace
restore

* Collapse per earnings growth distribution *

preserve
keep if n_res==10  | n_res==50  | n_res==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n_res)
save desc_res_ben_overall, replace
restore

preserve
keep if n_res_educ==10  | n_res_educ==50  | n_res_educ==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n_res_educ educ)
save desc_res_ben_educ, replace
restore

preserve
keep if n_res_imm==10  | n_res_imm==50  | n_res_imm==90
collapse forversreal totincreal labincreal selfincreal share* ind* ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal d_*, ///
by(year male n_res_imm foreignb)
save desc_res_ben_imm, replace
restore

*** Overall perc ***

use desc_ben_overall, clear

keep if year>=1995

drop ind_permearn ind_researn1F

reshape wide forversreal totincreal labincreal selfincreal ///
unempreal parbenreal sickbenreal disbenreal sdibenreal benefitsreal rembenreal ///
shareben shareui sharepl sharesi sharedi sharesdi shareremben ///
indbenefits indunemp indparben indsickben inddisben indsdiben indremben ///
d_ben d_shareben d_entryben d_exitben d_unemp d_entryunemp d_exitunemp ///
d_parben d_entryparben d_exitparben d_sickben d_entrysickben ///
d_exitsickben d_disben d_entrydisben d_exitdisben d_sdiben d_entrysdiben ///
d_exitsdiben d_remben d_entryremben d_exitremben ///
d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi d_shareremben d_ben_tot, ///
i(year male) j(n)

foreach var in forversreal totincreal labincreal selfincreal ///
unempreal parbenreal sickbenreal disbenreal sdibenreal benefitsreal rembenreal ///
shareben shareui sharepl sharesi sharedi sharesdi shareremben ///
indbenefits indunemp indparben indsickben inddisben indsdiben indremben ///
d_ben d_shareben d_entryben d_exitben d_unemp d_entryunemp d_exitunemp ///
d_parben d_entryparben d_exitparben d_sickben d_entrysickben ///
d_exitsickben d_disben d_entrydisben d_exitdisben d_sdiben d_entrysdiben ///
d_exitsdiben d_remben d_entryremben d_exitremben ///
d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi d_shareremben d_ben_tot{
label var `var'10 "P10"
label var `var'50 "P50"
label var `var'90 "P90"
}
label var year Year

save desc_ben_overall_wide, replace

* Share benefits combined graph *

use desc_ben_overall_wide, replace
keep year male shareben*
reshape wide shareben*, i(year) j(male)

foreach var in shareben{
label var `var'100 "P10 Women"
label var `var'500 "P50 Women"
label var `var'900 "P90 Women"
label var `var'101 "P10 Men"
label var `var'501 "P50 Men"
label var `var'901 "P90 Men"
}

* Share benefits *
twoway (line shareben* year), ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_share_pooled", replace)
	graph export "P:\2019\66\Output\ben_share_pooled.pdf", replace

*** By gender ***
	
use desc_ben_overall_wide, replace

* Share benefits *
twoway (line shareben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_share_women", replace)
	graph export "P:\2019\66\Output\ben_share_women.pdf", replace

twoway (line shareben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_share_men", replace)
	graph export "P:\2019\66\Output\ben_share_men.pdf", replace

* Share type benefits P10 *
label var shareui10 "Unemployment"
label var sharepl10 "Parental leave"
label var sharesdi10 "Sickness/disability"
label var shareremben10 "Studies+other"
twoway (line shareui10 sharepl10 sharesdi10 ///
shareremben10 year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.05)0.22) yscale(range(0 0.22)) legend(cols(2) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentype_share_women", replace)
	graph export "P:\2019\66\Output\bentype_share_women.pdf", replace

twoway (line shareui10 sharepl10 sharesdi10 ///
shareremben10 year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.05)0.22) yscale(range(0 0.22)) legend(cols(2) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentype_share_men", replace)
	graph export "P:\2019\66\Output\bentype_share_men.pdf", replace	
	
*** Fig: Share taking up benefits ***
twoway (line indbenefits* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.2)1) yscale(range(0 1)) legend(cols(1) ring(0) bplacement(seast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_women", replace)
	graph export "P:\2019\66\Output\ben_ext_women.pdf", replace

twoway (line indbenefits* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.2)1) yscale(range(0 1)) legend(cols(1) ring(0) bplacement(seast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_men", replace)
	graph export "P:\2019\66\Output\ben_ext_men.pdf", replace

*** Figs: Share taking up benefits by benefits type ***

* Indicator ui benefits *
twoway (line indunemp* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_women_unemp", replace)
	graph export "P:\2019\66\Output\ben_ext_women_unemp.pdf", replace

twoway (line indunemp* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_men_unemp", replace)
	graph export "P:\2019\66\Output\ben_ext_men_unemp.pdf", replace

* Indicator pl benefits *
twoway (line indparben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(seast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_women_parben", replace)
	graph export "P:\2019\66\Output\ben_ext_women_parben.pdf", replace

twoway (line indparben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(seast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_men_parben", replace)
	graph export "P:\2019\66\Output\ben_ext_men_parben.pdf", replace

* Indicator sdi benefits *
twoway (line indsdiben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_women_sdiben", replace)
	graph export "P:\2019\66\Output\ben_ext_women_sdiben.pdf", replace

twoway (line indsdiben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_men_sdiben", replace)
	graph export "P:\2019\66\Output\ben_ext_men_sdiben.pdf", replace

* Indicator other benefits *
twoway (line indremben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.2)0.6) yscale(range(0 0.65)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_women_remben", replace)
	graph export "P:\2019\66\Output\ben_ext_women_remben.pdf", replace

twoway (line indremben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.2)0.6) yscale(range(0 0.65)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_ext_men_remben", replace)
	graph export "P:\2019\66\Output\ben_ext_men_remben.pdf", replace

* Benefits types *
label var unempreal10 "Unemployment"
label var parbenreal10 "Parental leave"
label var sickbenreal10 "Sickness benefits"
label var disbenreal10 "Disability benefits"
label var rembenreal10 "Study benefits + other"
twoway (line unempreal10 parbenreal10 sickbenreal10 disbenreal10 ///
rembenreal10 year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Real benefits, SEK") title("Benefits types, Women P10")	///
	ylabel(0(20000)40000) yscale(range(0 50000)) legend(cols(2)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_type_women", replace)
	graph export "P:\2019\66\Output\ben_type_women.pdf", replace

twoway (line unempreal10 parbenreal10 sickbenreal10 disbenreal10 ///
rembenreal10 year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Real benefits, SEK") title("Benefits types, Men P10")	///
	ylabel(0(20000)40000) yscale(range(0 50000)) legend(cols(2)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_type_men", replace)
	graph export "P:\2019\66\Output\ben_type_men.pdf", replace

* Change benefits *
twoway (line d_ben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("1-y change benefits") title("Change benefits, Women")	///
	ylabel(-10000(10000)40000) yscale(range(-10000 40000)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\d_ben_women", replace)
	graph export "P:\2019\66\Output\d_ben_women.pdf", replace

twoway (line d_ben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("1-y change benefits") title("Change benefits, Men")	///
	ylabel(-10000(10000)40000) yscale(range(-10000 40000)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\d_ben_men", replace)
	graph export "P:\2019\66\Output\d_ben_men.pdf", replace

* Change share benefits *
twoway (line d_shareben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("1-y change share benefits") title("Change share benefits, Women")	///
	ylabel(-0.1(0.1)0.2) yscale(range(-0.1 0.2)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\d_shareben_women", replace)
	graph export "P:\2019\66\Output\d_shareben_women.pdf", replace

twoway (line d_shareben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("1-y change share benefits") title("Change share benefits, Men")	///
	ylabel(-0.1(0.1)0.2) yscale(range(-0.1 0.2)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\d_shareben_men", replace)
	graph export "P:\2019\66\Output\d_shareben_men.pdf", replace

*** Benefits by education group and percentiles ***

use desc_ben_educ, clear
 
keep if year>=1995

drop ind_permearn ind_researn1F

reshape wide forversreal totincreal labincreal selfincreal ///
unempreal parbenreal sickbenreal disbenreal sdibenreal benefitsreal rembenreal ///
shareben shareui sharepl sharesi sharedi sharesdi shareremben ///
indbenefits indunemp indparben indsickben inddisben indsdiben indremben ///
d_ben d_shareben d_entryben d_exitben d_unemp d_entryunemp d_exitunemp ///
d_parben d_entryparben d_exitparben d_sickben d_entrysickben ///
d_exitsickben d_disben d_entrydisben d_exitdisben d_sdiben d_entrysdiben ///
d_exitsdiben d_remben d_entryremben d_exitremben ///
d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi d_shareremben d_ben_tot, ///
i(year male educ) j(n_educ)

foreach var in forversreal totincreal labincreal selfincreal ///
unempreal parbenreal sickbenreal disbenreal sdibenreal benefitsreal rembenreal ///
shareben shareui sharepl sharesi sharedi sharesdi shareremben ///
indbenefits indunemp indparben indsickben inddisben indsdiben indremben ///
d_ben d_shareben d_entryben d_exitben d_unemp d_entryunemp d_exitunemp ///
d_parben d_entryparben d_exitparben d_sickben d_entrysickben ///
d_exitsickben d_disben d_entrydisben d_exitdisben d_sdiben d_entrysdiben ///
d_exitsdiben d_remben d_entryremben d_exitremben ///
d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi d_shareremben d_ben_tot{
label var `var'10 "P10"
label var `var'50 "P50"
label var `var'90 "P90"
}
label var year Year

save desc_ben_educ_wide, replace

forvalues I=1/2{
use desc_ben_educ_wide, clear
keep if educ==`I'

* Share benefits *
twoway (line shareben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits as share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016))	///
	saving("P:\2019\66\Output\ben_share_women_educ`I'", replace)
	graph export "P:\2019\66\Output\ben_share_women_educ`I'.pdf", replace

twoway (line shareben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits as share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_share_men_educ`I'", replace)
	graph export "P:\2019\66\Output\ben_share_men_educ`I'.pdf", replace
}
	
*** Benefits by origin and percentiles ***

use desc_ben_imm, clear

keep if year>=1995

drop ind_permearn ind_researn1F

reshape wide forversreal totincreal labincreal selfincreal shareben shareui ///
sharepl sharesi sharedi sharesdi shareremben indbenefits indunemp indparben ///
indsickben inddisben indsdiben indremben unempreal parbenreal sickbenreal ///
disbenreal sdibenreal rembenreal benefitsreal d_ben d_shareben d_entryben ///
d_exitben d_unemp d_entryunemp d_exitunemp d_parben d_entryparben ///
d_exitparben d_sickben d_entrysickben d_exitsickben d_disben d_entrydisben ///
d_exitdisben d_sdiben d_entrysdiben d_exitsdiben d_remben d_entryremben ///
d_exitremben d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi ///
d_shareremben d_ben_tot, ///
i(year male foreignb) j(n_imm)

foreach var in forversreal totincreal labincreal selfincreal shareben shareui ///
sharepl sharesi sharedi sharesdi shareremben indbenefits indunemp indparben ///
indsickben inddisben indsdiben indremben unempreal parbenreal sickbenreal ///
disbenreal sdibenreal rembenreal benefitsreal d_ben d_shareben d_entryben ///
d_exitben d_unemp d_entryunemp d_exitunemp d_parben d_entryparben ///
d_exitparben d_sickben d_entrysickben d_exitsickben d_disben d_entrydisben ///
d_exitdisben d_sdiben d_entrysdiben d_exitsdiben d_remben d_entryremben ///
d_exitremben d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi ///
d_shareremben d_ben_tot{
label var `var'10 "P10"
label var `var'25 "P25"
label var `var'50 "P50"
label var `var'90 "P90"
}
label var year Year

save desc_ben_imm_wide, replace

*** Fig: Benefits share by origin ***

forvalues I=0/1{
use desc_ben_imm_wide, clear
drop *25
keep if foreignb==`I'

* Share benefits *
twoway (line shareben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_share_women_imm`I'", replace)
	graph export "P:\2019\66\Output\ben_share_women_imm`I'.pdf", replace

twoway (line shareben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.5)) legend(cols(1) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\ben_share_men_imm`I'", replace)
	graph export "P:\2019\66\Output\ben_share_men_imm`I'.pdf", replace

*** Fig: Benefits type by origin P10 *

label var shareui10 "Unemployment"
label var sharepl10 "Parental leave"
label var sharesdi10 "Sickness/Disability"
label var shareremben10 "Studies+Other"
twoway (line shareui10 sharepl10 sharesdi10 shareremben10 year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.3) yscale(range(0 0.3)) legend(cols(2) ring(0) bplacement(neast))  ///
	xlabel(1995(5)2015) xscale(range(1995 2016))	///
	saving("P:\2019\66\Output\bentype_share_women_imm`I'", replace)
	graph export "P:\2019\66\Output\bentype_share_women_imm`I'.pdf", replace

twoway (line shareui10 sharepl10 sharesdi10 shareremben10 year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.3) yscale(range(0 0.3)) legend(cols(2) ring(0) bplacement(neast))  ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentype_share_men_imm`I'", replace)
	graph export "P:\2019\66\Output\bentype_share_men_imm`I'.pdf", replace	
}

*** Fig: Benefits share at P10 combined figure *

use desc_ben_imm_wide, clear
keep year shareben10 male foreignb
reshape wide shareben10, i(year foreignb) j(male)
reshape wide shareben10*, i(year) j(foreignb)

label var shareben1000 "Native Women"
label var shareben1010 "Native Men"
label var shareben1001 "Foreign-born Women"
label var shareben1011 "Foreign-born Men"

twoway (line shareben* year), ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.55)) legend(cols(2) ring(0) bplacement(seast))  ///
	xlabel(1995(5)2015) xscale(range(1995 2016))	///
	saving("P:\2019\66\Output\ben_share_imm", replace)
	graph export "P:\2019\66\Output\ben_share_imm.pdf", replace

*** Fig: Benefits share at P25 combined figure *

use desc_ben_imm_wide, clear
keep year shareben25 male foreignb
reshape wide shareben25, i(year foreignb) j(male)
reshape wide shareben25*, i(year) j(foreignb)

label var shareben2500 "Native Women"
label var shareben2510 "Native Men"
label var shareben2501 "Foreign-born Women"
label var shareben2511 "Foreign-born Men"

twoway (line shareben* year), ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.5) yscale(range(0 0.55)) legend(cols(2) ring(0) bplacement(neast))  ///
	xlabel(1995(5)2015) xscale(range(1995 2016))	///
	saving("P:\2019\66\Output\ben_share_imm_p25", replace)
	graph export "P:\2019\66\Output\ben_share_imm_p25.pdf", replace

*** Benefits by west/nonwest and percentiles ***

use desc_ben_nonwest, clear

keep if year>=1995

drop ind_permearn ind_researn1F

reshape wide forversreal totincreal labincreal selfincreal shareben shareui ///
sharepl sharesi sharedi sharesdi shareremben indbenefits indunemp indparben ///
indsickben inddisben indsdiben indremben unempreal parbenreal sickbenreal ///
disbenreal sdibenreal rembenreal benefitsreal d_ben d_shareben d_entryben ///
d_exitben d_unemp d_entryunemp d_exitunemp d_parben d_entryparben ///
d_exitparben d_sickben d_entrysickben d_exitsickben d_disben d_entrydisben ///
d_exitdisben d_sdiben d_entrysdiben d_exitsdiben d_remben d_entryremben ///
d_exitremben d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi ///
d_shareremben d_ben_tot, ///
i(year male nonwest) j(n_nonwest)

foreach var in forversreal totincreal labincreal selfincreal shareben shareui ///
sharepl sharesi sharedi sharesdi shareremben indbenefits indunemp indparben ///
indsickben inddisben indsdiben indremben unempreal parbenreal sickbenreal ///
disbenreal sdibenreal rembenreal benefitsreal d_ben d_shareben d_entryben ///
d_exitben d_unemp d_entryunemp d_exitunemp d_parben d_entryparben ///
d_exitparben d_sickben d_entrysickben d_exitsickben d_disben d_entrydisben ///
d_exitdisben d_sdiben d_entrysdiben d_exitsdiben d_remben d_entryremben ///
d_exitremben d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi ///
d_shareremben d_ben_tot{
label var `var'10 "P10"
label var `var'50 "P50"
label var `var'90 "P90"
}
label var year Year

save desc_ben_nonwest_wide, replace

*** Fig: Benefits share at P10 combined figure *

use desc_ben_nonwest_wide, clear
keep year shareben10 male nonwest
reshape wide shareben10, i(year nonwest) j(male)
reshape wide shareben10*, i(year) j(nonwest)

label var shareben1000 "EUAM Women"
label var shareben1010 "EUAM Men"
label var shareben1001 "AAME Women"
label var shareben1011 "AAME Men"

twoway (line shareben* year), ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Benefits share of total work-related income") ///
	ylabel(0(0.1)0.6) yscale(range(0 0.6)) legend(cols(2) ring(0) bplacement(seast))  ///
	xlabel(1995(5)2015) xscale(range(1995 2016))	///
	saving("P:\2019\66\Output\ben_share_nonwest_P10", replace)
	graph export "P:\2019\66\Output\ben_share_nonwest_P10.pdf", replace

*** Fig: Overall description on benefits ***

use "P:\2019\66\Use\desc_benefits.dta", clear
keep if year>=1995
collapse indunemp indparben indsdiben indremben ///
unempreal parbenreal sdibenreal rembenreal, by(year male)
save desc_bentypes_overall, replace

use desc_bentypes_overall, clear
label var indunemp "Unemployment"
label var indparben "Parental leave"
label var indsdiben "Sickness/Disability"
label var indremben "Studies+Other"

foreach var in unempreal parbenreal sdibenreal rembenreal{
replace `var'=`var'/8.6945
}

label var unempreal "Unemployment"
label var parbenreal "Parental leave"
label var sdibenreal "Sickness/Disability"
label var rembenreal "Studies+Other"
label var year Year

twoway (line unempreal parbenreal sdibenreal rembenreal year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Average benefit amount, 2018 USD")	///
	ylabel(0(500)1300) yscale(range(0 1300)) legend(cols(2) ring(0) bplacement(seast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentypes_amount_overall_women", replace)
	graph export "P:\2019\66\Output\bentypes_amount_overall_women.pdf", replace

twoway (line unempreal parbenreal sdibenreal rembenreal year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Average benefit amount, 2018 USD")	///
	ylabel(0(500)1300) yscale(range(0 1300)) legend(cols(2) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentypes_amount_overall_men", replace)
	graph export "P:\2019\66\Output\bentypes_amount_overall_men.pdf", replace

twoway (line ind* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.45) yscale(range(0 0.45)) legend(cols(2) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentypes_share_overall_women", replace)
	graph export "P:\2019\66\Output\bentypes_share_overall_women.pdf", replace

twoway (line ind* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2) ///
	ytitle("Share taking up benefits")	///
	ylabel(0(0.1)0.45) yscale(range(0 0.45)) legend(cols(2) ring(0) bplacement(neast)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\bentypes_share_overall_men", replace)
	graph export "P:\2019\66\Output\bentypes_share_overall_men.pdf", replace

*** Figures growth distribution ***

*** Overall perc ***
use desc_res_ben_overall, clear

keep if year>=1995

drop ind_permearn ind_researn1F

reshape wide forversreal totincreal labincreal selfincreal ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal ///
shareben shareui sharepl sharesi sharedi sharesdi shareremben ///
indbenefits indunemp indparben indsickben inddisben indsdiben indremben ///
d_ben d_shareben d_entryben d_exitben d_unemp d_entryunemp d_exitunemp ///
d_parben d_entryparben d_exitparben d_sickben d_entrysickben ///
d_exitsickben d_disben d_entrydisben d_exitdisben d_sdiben d_entrysdiben d_exitsdiben d_remben d_entryremben ///
d_exitremben d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi d_shareremben d_ben_tot, ///
i(year male) j(n_res)

foreach var in forversreal totincreal labincreal selfincreal ///
unempreal parbenreal sickbenreal disbenreal sdibenreal rembenreal benefitsreal ///
shareben shareui sharepl sharesi sharedi sharesdi shareremben ///
indbenefits indunemp indparben indsickben inddisben indsdiben indremben ///
d_ben d_shareben d_entryben d_exitben d_unemp d_entryunemp d_exitunemp ///
d_parben d_entryparben d_exitparben d_sickben d_entrysickben ///
d_exitsickben d_disben d_entrydisben d_exitdisben d_sdiben d_entrysdiben d_exitsdiben d_remben d_entryremben ///
d_exitremben d_shareui d_sharepl d_sharesi d_sharedi d_sharesdi d_shareremben d_ben_tot{
label var `var'10 "P10"
label var `var'50 "P50"
label var `var'90 "P90"
}
label var year Year

save desc_res_ben_overall_wide, replace

use desc_res_ben_overall_wide, replace

* Share benefits *
twoway (line d_shareben* year) if male==0, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Change benefits share of tot work-rel income") ///
	ylabel(-0.2(0.1)0.2) yscale(range(-0.2 0.25)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\d_ben_share_women", replace)
	graph export "P:\2019\66\Output\d_ben_share_women.pdf", replace

twoway (line d_shareben* year) if male==1, ///
	scheme(s2mono) graphregion(color(white)) scale(1.2)	///
	ytitle("Change benefits share of tot work-rel income") ///
	ylabel(-0.2(0.1)0.2) yscale(range(-0.2 0.25)) legend(cols(3)) ///
	xlabel(1995(5)2015) xscale(range(1995 2016)) ///
	saving("P:\2019\66\Output\d_ben_share_men", replace)
	graph export "P:\2019\66\Output\d_ben_share_men.pdf", replace
